@@ -16,12 +16,13 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <qlayout.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 
 #include <kapp.h>
 
 #include "BackupOptDlg.h"
 #include "BackupProfileWidget.h"
+#include <klocale.h>
 
 #include "BackupOptDlg.moc"
 
