@@ -15,19 +15,20 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-#include <qchkbox.h>
-#include <qcombo.h>
+#include <qcheckbox.h>
+#include <qcombobox.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlined.h>
+#include <qlineedit.h>
 #include <qlistbox.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 
 #include <kapp.h>
 
 #include "BackupProfile.h"
 #include "BackupProfileWidget.h"
 #include "Util.h"
+#include <klocale.h>
 
 #include "BackupProfileWidget.moc"
 
