@@ -17,16 +17,17 @@
 
 #include <stdlib.h>
 
-#include <qcombo.h>
+#include <qcombobox.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlined.h>
-#include <qpushbt.h>
+#include <qlineedit.h>
+#include <qpushbutton.h>
 
 #include <kapp.h>
 
 #include "Options.h"
 #include "FormatOptDlg.h"
+#include <klocale.h>
 
 #include "FormatOptDlg.moc"
 
