@@ -20,19 +20,21 @@
 #include <unistd.h>
 #include <sys/stat.h>
 
-#include <qdatetm.h>
+#include <qdatetime.h>
 #include <qdir.h>
-#include <qfileinf.h>
+#include <qfileinfo.h>
 #include <qkeycode.h>
 #include <qlayout.h>
-#include <qmsgbox.h>
+#include <qtextstream.h>
+#include <qmessagebox.h>
 
 #include <kapp.h>
 #include <kiconloader.h>
 #include <kmenubar.h>
-#include <kmsgbox.h>
-#include <kpanner.h>
 #include <ktoolbar.h>
+#include <kglobal.h>
+#include <kconfig.h>
+#include <kmessagebox.h>
 
 #include "ArchiveInfoWidget.h"
 #include "BackupDlg.h"
@@ -60,12 +62,14 @@
 #include "VerifyOptDlg.h"
 #include "kdat.h"
 #include "ktreeview.h"
+#include <klocale.h>
+#include <qsplitter.h>
 
 #include "KDat.moc"
 
 KDat* KDat::_instance = 0;
 
-KDat* KDat::instance()
+KDat* KDat::getInstance()
 {
     if ( _instance == 0 ) {
         _instance = new KDat();
@@ -137,9 +141,8 @@ KDat::KDat()
     _menu->insertItem( i18n( "&File" ), _fileMenu );
     _menu->insertItem( i18n( "&Edit" ), _editMenu );
     _menu->insertSeparator();
-    QString about;
-    about.sprintf( i18n( "KDat Version %s\n\nKDat is a tar-based tape archiver.\n\nCopyright (c) 1998 Sean Vyain\nsvyain@mail.tds.net" ), KDAT_VERSION );
-    _menu->insertItem( i18n( "&Help" ), KApplication::getKApplication()->getHelpMenu( TRUE, about.data() ) );
+    QString about = i18n( "KDat Version %1\n\nKDat is a tar-based tape archiver.\n\nCopyright (c) 1998 Sean Vyain\nsvyain@mail.tds.net" ).arg( KDAT_VERSION );
+    _menu->insertItem( i18n( "&Help" ), helpMenu( about.data() ) );
 
     setMenu( _menu );
     
@@ -155,12 +158,11 @@ KDat::KDat()
 
     _toolbar->insertSeparator();
 
-    KIconLoader* iconLoader = KApplication::getKApplication()->getIconLoader();
-    _toolbar->insertButton( iconLoader->loadIcon( "help.xpm" ), 4, SIGNAL( clicked( int ) ), this, SLOT( help() )    , TRUE, i18n( "Help" ) );
+    _toolbar->insertButton( BarIcon( "help" ), 4, SIGNAL( clicked( int ) ), this, SLOT( help() )    , TRUE, i18n( "Help" ) );
 
     _toolbar->insertSeparator();
 
-    _toolbar->insertButton( iconLoader->loadIcon( "exit.xpm" ), 5, SIGNAL( clicked( int ) ), this, SLOT( fileQuit() ), TRUE, i18n( "Quit" ) );
+    _toolbar->insertButton( BarIcon( "exit" ), 5, SIGNAL( clicked( int ) ), this, SLOT( fileQuit() ), TRUE, i18n( "Quit" ) );
 
     addToolBar( _toolbar );
 
@@ -168,11 +170,11 @@ KDat::KDat()
     _statusBar->insertItem( i18n( "Ready." ), 0 );
     setStatusBar( _statusBar );
 
-    _panner = new KPanner( this, "panner", KPanner::O_VERTICAL | KPanner::U_PERCENT, 50 );
+    _panner = new QSplitter( QSplitter::Vertical, this, "panner");
 
     // Create info viewers.
-    InfoShellWidget* infoShell = new InfoShellWidget( _panner->child1() );
-    QVBoxLayout* infoLayout = new QVBoxLayout( _panner->child1(), 4, 4 );
+    InfoShellWidget* infoShell = new InfoShellWidget( _panner );
+    QVBoxLayout* infoLayout = new QVBoxLayout( _panner, 4, 4 );
     infoLayout->addWidget( infoShell );
     _tapeInfo = new TapeInfoWidget( infoShell );
     _archiveInfo = new ArchiveInfoWidget( infoShell );
@@ -180,11 +182,11 @@ KDat::KDat()
     _tapeFileInfo = new TapeFileInfoWidget( infoShell );
     _fileInfo = new FileInfoWidget( infoShell );
 
-    _tree = new KTreeView( _panner->child0() );
+    _tree = new KTreeView( _panner );
 
     _tree->setExpandButtonDrawing( TRUE );
 
-    QVBoxLayout* localLayout = new QVBoxLayout( _panner->child0(), 4, 4 );
+    QVBoxLayout* localLayout = new QVBoxLayout( _panner, 4, 4 );
 
     localLayout->addWidget( _tree, 1 );
 
@@ -394,10 +396,7 @@ void KDat::fileBackup()
         backupProfile.setRemoveSnapshot( bp->getRemoveSnapshot() );
     } else {
         QString name;
-        time_t tm = time( NULL );
-        char date[80];
-        strftime( date, 80, i18n( "%m/%d/%y" ), localtime( &tm ) );
-        name.sprintf( i18n( "Archive created on %s" ), date );
+        name = i18n( "Archive created on %1" ).arg( KGlobal::locale()->formatDate(QDate::currentDate(), true) );
         name = name.stripWhiteSpace();
         
         QStrList files;
@@ -429,7 +428,8 @@ void KDat::fileBackup()
             // Warn user that tape is probably too short.
             QString msg;
             msg.sprintf( i18n( "WARNING: The estimated archive size is %dKB.\nThe tape has only %dKB of space!\n\nBackup anyway?" ), size, TapeManager::instance()->getMountedTape()->getSize() - tapeSize );
-            if ( KMsgBox::yesNo( this, i18n( "KDat: Backup" ), msg, KMsgBox::EXCLAMATION ) != 1 ) {
+            if ( QMessageBox::warning( this, i18n( "KDat: Backup" ), 
+				       msg, i18n("Yes"), i18n("No") ) != 0 ) {
                 status( i18n( "Backup canceled." ) );
                 return;
             }
@@ -439,7 +439,8 @@ void KDat::fileBackup()
             // Rewind tape.
             status( i18n( "Rewinding tape..." ) );
             if ( !TapeDrive::instance()->rewind() ) {
-                KMsgBox::message( this, i18n( "KDat: Cannot Rewind Tape" ), i18n( "Cannot rewind tape.  Backup aborted." ), KMsgBox::EXCLAMATION );
+                QMessageBox::warning( this, i18n( "KDat: Cannot Rewind Tape" ),
+				      i18n( "Cannot rewind tape.  Backup aborted." ), i18n("OK"));
                 status( i18n( "Backup aborted." ) );
                 return;
             }
@@ -448,7 +449,9 @@ void KDat::fileBackup()
         // Go to end of tape.
         status( i18n( "Skipping to end of tape..." ) );
         if ( !TapeDrive::instance()->nextFile( TapeManager::instance()->getMountedTape()->getChildren().count() + 1 - TapeDrive::instance()->getFile() ) ) {
-            KMsgBox::message( this, i18n( "KDat: Error" ), i18n( "Cannot get to end of tape." ), KMsgBox::EXCLAMATION );
+            QMessageBox::warning( this, i18n( "KDat: Error" ), 
+				  i18n( "Cannot get to end of tape." ),
+				  i18n("OK"));
             status( i18n( "Backup aborted." ) );
             return;
         }
@@ -616,7 +619,7 @@ void KDat::fileMountTape()
     if ( !TapeManager::instance()->getMountedTape() ) {
         if ( Options::instance()->getLoadOnMount() ) {
             if ( !TapeDrive::instance()->load() ) {
-                KMsgBox::message( this, i18n( "KDat: No Tape" ), i18n( "There is no tape in the drive." ), KMsgBox::EXCLAMATION );
+                QMessageBox::information( this, i18n( "KDat: No Tape" ), i18n( "There is no tape in the drive." ), i18n("OK"));
                 return;
             }
         }
@@ -624,7 +627,7 @@ void KDat::fileMountTape()
         if ( TapeDrive::instance()->isTapePresent() ) {
             setTapePresent( TRUE );
         } else {
-            KMsgBox::message( this, i18n( "KDat: No Tape" ), i18n( "There is no tape in the drive." ), KMsgBox::EXCLAMATION );
+            QMessageBox::warning( this, i18n( "KDat: No Tape" ), i18n( "There is no tape in the drive." ), i18n("OK"));
         }
     } else {
         setTapePresent( FALSE );
@@ -633,12 +636,13 @@ void KDat::fileMountTape()
 
 void KDat::fileIndexTape()
 {
-    if ( KMsgBox::yesNo( this, i18n( "KDat: Index Tape" ), i18n( "The current tape index will be overwritten, continue?" ), KMsgBox::EXCLAMATION ) == 1 ) {
+    if ( QMessageBox::warning( this, i18n( "KDat: Index Tape" ), 
+			       i18n( "The current tape index will be overwritten, continue?" ), i18n("Yes - Overwrite"), i18n("No") ) == 0 ) {
         TapeManager::instance()->getMountedTape()->clear();
         IndexDlg dlg( TapeManager::instance()->getMountedTape(), this );
         if ( dlg.exec() == QDialog::Accepted ) {
             QString title;
-            title.sprintf( i18n( "KDat: %s" ), TapeManager::instance()->getMountedTape()->getName().data() );
+            title = i18n( "KDat: %1" ).arg( TapeManager::instance()->getMountedTape()->getName() );
             setCaption( title );
             setIconText( title );
 
@@ -653,7 +657,7 @@ void KDat::fileDeleteArchive()
 {
     Node* sel = (Node*)_tree->getCurrentItem();
     if ( ( !sel ) || ( !sel->isType( Node::ArchiveNodeType ) && !sel->isType( Node::MountedArchiveNodeType ) ) ) {
-        KMsgBox::message( this, i18n( "KDat: No Archive Selected" ), i18n( "An archive must be selected in the tree." ), KMsgBox::EXCLAMATION );
+       QMessageBox::warning( this, i18n( "KDat: No Archive Selected" ), i18n( "An archive must be selected in the tree." ), i18n("OK"));
         return;
     }
 
@@ -685,9 +689,9 @@ void KDat::fileDeleteArchive()
         }
 
         QString msg;
-        msg.resize( 32768 );
-        msg.sprintf( i18n( "An archive cannot be removed from the middle of the tape.  If\nthe archive '%s' is deleted then\nthe following archives will also be deleted:\n%s\n\n Delete all listed archives?" ), archive->getName().data(), list.data() );
-        if ( KMsgBox::yesNo( this, i18n( "KDat: Delete Archives?" ), msg, KMsgBox::EXCLAMATION ) == 1 ) {
+        // msg.truncate( 32767 );
+        msg = i18n( "An archive cannot be removed from the middle of the tape. If\nthe archive '%1' is deleted then\nthe following archives will also be deleted:\n%2\n\n Delete all listed archives?" ).arg(archive->getName()).arg(list);
+        if ( QMessageBox::warning( this, i18n( "KDat: Delete Archives?" ), msg, i18n("Yes"), i18n("No") ) == 0 ) {
             tape->removeChild( archive );
             emit status( i18n( "Archives deleted." ) );
             if ( _tree->getCurrentItem() ) {
@@ -698,8 +702,8 @@ void KDat::fileDeleteArchive()
     } else {
         // This is the last (known) archive on the tape.
         QString msg;
-        msg.sprintf( i18n( "Really delete the archive '%s'?" ), archive->getName().data() );
-        if ( KMsgBox::yesNo( this, i18n( "KDat: Delete Archive?" ), msg, KMsgBox::EXCLAMATION ) == 1 ) {
+        msg = i18n( "Really delete the archive '%1'?" ).arg(archive->getName());
+        if ( QMessageBox::warning( this, i18n( "KDat: Delete Archive?" ), msg, i18n("Yes") ) == 0 ) {
             tape->removeChild( archive );
             emit status( i18n( "Archive deleted." ) );
             if ( _tree->getCurrentItem() ) {
@@ -714,20 +718,20 @@ void KDat::fileDeleteIndex()
 {
     Node* sel = (Node*)_tree->getCurrentItem();
     if ( ( !sel ) || ( !sel->isType( Node::TapeNodeType ) ) ) {
-        KMsgBox::message( this, i18n( "KDat: No Tape Index Selected" ), i18n( "A tape index must be selected in the tree." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( this, i18n( "KDat: No Tape Index Selected" ), i18n( "A tape index must be selected in the tree." ), i18n("OK") );
         return;
     }
 
     Tape* tape = ((TapeNode*)sel)->getTape();
     assert( tape );
     if ( tape == TapeManager::instance()->getMountedTape() ) {
-        KMsgBox::message( this, i18n( "KDat: Tape Is Mounted" ), i18n( "The index for a mounted tape cannot be deleted.\n\nUnmount the tape and try again." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( this, i18n( "KDat: Tape Is Mounted" ), i18n( "The index for a mounted tape cannot be deleted.\n\nUnmount the tape and try again." ), i18n("OK") );
         return;
     }
 
     QString msg;
-    msg.sprintf( i18n( "Really delete the index for '%s'?" ), tape->getName().data() );
-    if ( KMsgBox::yesNo( this, i18n( "KDat: Delete Tape Index?" ), msg, KMsgBox::EXCLAMATION ) == 1 ) {
+    msg = i18n( "Really delete the index for '%1'?" ).arg(tape->getName());
+    if ( QMessageBox::warning( this, i18n( "KDat: Delete Tape Index?" ), msg, i18n("OK") ) == 0 ) {
         TapeManager::instance()->removeTape( tape );
         emit status( i18n( "Tape index deleted." ) );
         if ( _tree->getCurrentItem() ) {
@@ -740,21 +744,18 @@ void KDat::fileDeleteIndex()
 void KDat::fileFormatTape()
 {
     if ( !TapeDrive::instance()->isTapePresent() ) {
-        KMsgBox::message( this, i18n( "KDat: No Tape In Drive" ), i18n( "There is no tape in the tape drive.\nPlease insert a tape and try again." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( this, i18n( "KDat: No Tape In Drive" ), i18n( "There is no tape in the tape drive.\nPlease insert a tape and try again." ), i18n("OK") );
         return;
     }
 
     if ( TapeDrive::instance()->isReadOnly() ) {
-        KMsgBox::message( this, i18n( "KDat: Write Protected Tape" ), i18n( "The tape in the drive is write protected.\nPlease disable write protection and try again." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( this, i18n( "KDat: Write Protected Tape" ), i18n( "The tape in the drive is write protected.\nPlease disable write protection and try again." ), i18n("OK") );
         return;
     }
 
-    if ( KMsgBox::yesNo( this, i18n( "KDat: Format Tape" ), i18n( "All data will be lost, continue?" ), KMsgBox::EXCLAMATION ) == 1 ) {
+    if ( KMessageBox::warningYesNo( this, i18n( "Format Tape" ), i18n( "All data will be lost, continue?" )) == 3 ) {
         QString name;
-        time_t tm = time( NULL );
-        char date[80];
-        strftime( date, 80, i18n( "%m/%d/%y" ), localtime( &tm ) );
-        name.sprintf( i18n( "Tape created on %s" ), date );
+        name = i18n( "Tape created on %1" ).arg(  KGlobal::locale()->formatDate(QDate::currentDate(), true) );
         FormatOptDlg dlg( name.stripWhiteSpace(), this );
         if ( dlg.exec() != QDialog::Accepted ) {
             return;
@@ -825,7 +826,7 @@ void KDat::fileDeleteBackupProfile()
 {
     Node* sel = (Node*)_tree->getCurrentItem();
     if ( ( !sel ) || ( !sel->isType( Node::BackupProfileNodeType ) ) ) {
-        KMsgBox::message( this, i18n( "KDat: No Backup Profile Selected" ), i18n( "A backup profile must be selected in the tree." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( this, i18n( "KDat: No Backup Profile Selected" ), i18n( "A backup profile must be selected in the tree." ), i18n("OK") );
         return;
     }
 
@@ -833,8 +834,8 @@ void KDat::fileDeleteBackupProfile()
     assert( backupProfile );
 
     QString msg;
-    msg.sprintf( i18n( "Really delete backup profile '%s'?" ), backupProfile->getName() );
-    if ( KMsgBox::yesNo( this, i18n( "KDat: Delete Backup Profile?" ), msg, KMsgBox::EXCLAMATION ) == 1 ) {
+    msg = i18n("Really delete backup profile '%1'?").arg(backupProfile->getName());
+    if ( QMessageBox::warning( this, i18n( "KDat: Delete Backup Profile?" ), msg, i18n("Yes"), i18n("No") ) == 0 ) {
         BackupProfileManager::instance()->removeBackupProfile( backupProfile );
         emit status( i18n( "Backup profile deleted." ) );
         if ( _tree->getCurrentItem() ) {
@@ -846,7 +847,7 @@ void KDat::fileDeleteBackupProfile()
 
 void KDat::fileQuit()
 {
-    KApplication::getKApplication()->quit();
+    KApplication::kApplication()->quit();
 }
 
 void KDat::editPreferences()
@@ -857,7 +858,7 @@ void KDat::editPreferences()
 
 void KDat::help()
 {
-    KApplication::getKApplication()->invokeHTMLHelp( "", "" );
+    KApplication::kApplication()->invokeHelp( );
 }
 
 void KDat::setTapePresent( bool tapePresent, bool eject )
@@ -885,9 +886,9 @@ void KDat::setTapePresent( bool tapePresent, bool eject )
                 TapeManager::instance()->mountTape( tape );
             } else {
                 if ( TapeDrive::instance()->isReadOnly() ) {
-                    KMsgBox::message( this, i18n( "KDat: Unformatted Tape" ), i18n( "This tape has not been formatted by KDat." ), KMsgBox::EXCLAMATION );
+                    QMessageBox::warning( this, i18n( "KDat: Unformatted Tape" ), i18n( "This tape has not been formatted by KDat." ), i18n("OK") );
                 } else {
-                    if ( KMsgBox::yesNo( this, i18n( "KDat: Unformatted Tape" ), i18n( "This tape has not been formatted by KDat.\n\nWould you like to format it now?" ), KMsgBox::EXCLAMATION ) == 1 ) {
+                    if ( QMessageBox::warning( this, i18n( "KDat: Unformatted Tape" ), i18n( "This tape has not been formatted by KDat.\n\nWould you like to format it now?" ), i18n("Yes"), i18n("No") ) == 0 ) {
                         fileFormatTape();
                         return;
                     }
@@ -906,12 +907,12 @@ void KDat::setTapePresent( bool tapePresent, bool eject )
 void KDat::status( const char* msg )
 {
     _statusBar->changeItem( msg, 0 );
-    KApplication::getKApplication()->processEvents();
+    KApplication::kApplication()->processEvents();
 }
 
 void KDat::show()
 {
-    KTopLevelWidget::show();
+    KTMainWindow::show();
 
     hideInfo();
 }
@@ -968,14 +969,14 @@ int KDat::calcBackupSize( const QString& workingDir, bool local, const QStrList&
         }
         
         QString msg;
-        msg.resize( 4096 );
+        // msg.truncate( 4095 );
         QDir dir;
         const QFileInfoList* infoList;
         while ( !dirStack.isEmpty() ) {
             QString* path = dirStack.pop();
-            msg.sprintf( i18n( "Estimating backup size: %s, %s" ), Util::kbytesToString( size / 2 ).data(), path->data() );
+            msg = i18n("Estimating backup size: %1, %2" ).arg(Util::kbytesToString( size / 2 )).arg(*path);
             status( msg.data() );
-            KApplication::getKApplication()->processEvents();
+            KApplication::kApplication()->processEvents();
             dir.setPath( *path );
             infoList = dir.entryInfoList( QDir::Hidden | QDir::Files | QDir::Dirs, 0 );
             if ( infoList ) {
@@ -1094,7 +1095,7 @@ void KDat::configureUI( Tape* tape )
     // Title bar
     if ( tape ) {
         QString title;
-        title.sprintf( i18n( "KDat: %s" ), tape->getName().data() );
+        title = i18n( "KDat: %1" ).arg(tape->getName());
         setCaption( title );
         setIconText( title );
     } else {
@@ -1159,10 +1160,12 @@ void KDat::configureUI( Tape* tape )
 
 void KDat::readProperties( KConfig* config )
 {
-    _panner->setSeparator( config->readNumEntry( "panner", 50 ) );
+  QValueList<int> sizes;
+  sizes << config->readNumEntry( "panner", 50 );
+  _panner->setSizes( sizes );
 }
 
 void KDat::saveProperties( KConfig* config )
 {
-    config->writeEntry( "panner", _panner->getSeparator() );
+    config->writeEntry( "panner", _panner->sizes().first());
 }
