@@ -33,6 +33,7 @@
 #include "Range.h"
 #include "Tape.h"
 #include "TapeManager.h"
+#include <klocale.h>
 
 #include "Node.moc"
 
@@ -125,7 +126,7 @@ void Node::collapsed()
 
 void Node::selected()
 {
-    KDat::instance()->hideInfo();
+    KDat::getInstance()->hideInfo();
 }
 
 void Node::popupMenu( const QPoint& )
@@ -219,12 +220,12 @@ void TapeNode::expanding( bool expand )
 
 void TapeNode::selected()
 {
-    KDat::instance()->showTapeInfo( _tape );
+    KDat::getInstance()->showTapeInfo( _tape );
 }
 
 void TapeNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupTapeMenu( p );
+    KDat::getInstance()->popupTapeMenu( p );
 }
 
 ArchiveNode* TapeNode::findArchiveNode( Archive* archive )
@@ -292,12 +293,12 @@ void ArchiveNode::expanding( bool expand )
 
 void ArchiveNode::selected()
 {
-    KDat::instance()->showArchiveInfo( _archive );
+    KDat::getInstance()->showArchiveInfo( _archive );
 }
 
 void ArchiveNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupArchiveMenu( p );
+    KDat::getInstance()->popupArchiveMenu( p );
 }
 
 TapeDirectoryNode::TapeDirectoryNode( File* file )
@@ -360,7 +361,7 @@ void TapeDirectoryNode::collapsed()
 
 void TapeDirectoryNode::selected()
 {
-    KDat::instance()->showTapeFileInfo( _file );
+    KDat::getInstance()->showTapeFileInfo( _file );
 }
 
 TapeFileNode::TapeFileNode( File* file )
@@ -392,7 +393,7 @@ bool TapeFileNode::isType( int type )
 
 void TapeFileNode::selected()
 {
-    KDat::instance()->showTapeFileInfo( _file );
+    KDat::getInstance()->showTapeFileInfo( _file );
 }
 
 SelectableNode::SelectableNode( int type, const char* text, const QPixmap& pixmap, int state )
@@ -603,7 +604,7 @@ void SelectableNode::setSelected( bool select )
 
     owner->repaint();
 
-    KDat::instance()->configureUI( TapeManager::instance()->getMountedTape() );
+    KDat::getInstance()->configureUI( TapeManager::instance()->getMountedTape() );
 }
 
 RangeableNode::RangeableNode( int type, const char* text, const QPixmap& pixmap, int state )
@@ -692,12 +693,12 @@ void MountedArchiveNode::expanding( bool expand )
 
 void MountedArchiveNode::selected()
 {
-    KDat::instance()->showArchiveInfo( _archive );
+    KDat::getInstance()->showArchiveInfo( _archive );
 }
 
 void MountedArchiveNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupMountedArchiveMenu( p );
+    KDat::getInstance()->popupMountedArchiveMenu( p );
 }
 
 MountedTapeDirectoryNode::MountedTapeDirectoryNode( File* file, int state )
@@ -802,12 +803,12 @@ void MountedTapeDirectoryNode::collapsed()
 
 void MountedTapeDirectoryNode::selected()
 {
-    KDat::instance()->showTapeFileInfo( _file );
+    KDat::getInstance()->showTapeFileInfo( _file );
 }
 
 void MountedTapeDirectoryNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupMountedTapeFileMenu( p );
+    KDat::getInstance()->popupMountedTapeFileMenu( p );
 }
 
 MountedTapeFileNode::MountedTapeFileNode( File* file, int state )
@@ -832,7 +833,6 @@ const char* MountedTapeFileNode::getFullPath()
 {
     if ( _fullPath.length() == 0 ) {
         _fullPath = getText();
-        _fullPath.detach();
         for ( Node* parent = (Node*)getParent(); !parent->isType( MountedArchiveNodeType ); parent = (Node*)parent->getParent() ) {
             _fullPath.prepend( "/" );
             _fullPath.prepend( parent->getText() );
@@ -880,12 +880,12 @@ bool MountedTapeFileNode::isType( int type )
 
 void MountedTapeFileNode::selected()
 {
-    KDat::instance()->showTapeFileInfo( _file );
+    KDat::getInstance()->showTapeFileInfo( _file );
 }
 
 void MountedTapeFileNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupMountedTapeFileMenu( p );
+    KDat::getInstance()->popupMountedTapeFileMenu( p );
 }
 
 ArchiveableNode::ArchiveableNode( int type, const char* text, const QPixmap& pixmap, int state )
@@ -1001,12 +1001,12 @@ void RootNode::collapsed()
 
 void RootNode::selected()
 {
-    KDat::instance()->showFileInfo( "/" );
+    KDat::getInstance()->showFileInfo( "/" );
 }
 
 void RootNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupLocalFileMenu( p );
+    KDat::getInstance()->popupLocalFileMenu( p );
 }
 
 DirectoryNode::DirectoryNode( const char* text, int state )
@@ -1127,12 +1127,12 @@ void DirectoryNode::selected()
     path.prepend( "/" );
     path = path.left( path.length() - 1 );
 
-    KDat::instance()->showFileInfo( path );
+    KDat::getInstance()->showFileInfo( path );
 }
 
 void DirectoryNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupLocalFileMenu( p );
+    KDat::getInstance()->popupLocalFileMenu( p );
 }
 
 FileNode::FileNode( const char* text, int state )
@@ -1170,12 +1170,12 @@ void FileNode::selected()
     path.prepend( "/" );
     path = path.left( path.length() - 1 );
 
-    KDat::instance()->showFileInfo( path );
+    KDat::getInstance()->showFileInfo( path );
 }
 
 void FileNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupLocalFileMenu( p );
+    KDat::getInstance()->popupLocalFileMenu( p );
 }
 
 TapeDriveNode::TapeDriveNode()
@@ -1220,15 +1220,15 @@ void TapeDriveNode::expanding( bool expand )
 void TapeDriveNode::selected()
 {
     if ( TapeManager::instance()->getMountedTape() ) {
-        KDat::instance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
+        KDat::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
     } else {
-        KDat::instance()->hideInfo();
+        KDat::getInstance()->hideInfo();
     }
 }
 
 void TapeDriveNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupTapeDriveMenu( p );
+    KDat::getInstance()->popupTapeDriveMenu( p );
 }
 
 void TapeDriveNode::slotTapeMounted()
@@ -1237,7 +1237,7 @@ void TapeDriveNode::slotTapeMounted()
     setText( TapeManager::instance()->getMountedTape()->getName() );
 
     if ( this == owner->getCurrentItem() ) {
-        KDat::instance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
+        KDat::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
     }
 
     if ( isExpanded() ) {
@@ -1259,7 +1259,7 @@ void TapeDriveNode::slotTapeUnmounted()
     }
 
     if ( this == owner->getCurrentItem() ) {
-        KDat::instance()->hideInfo();
+        KDat::getInstance()->hideInfo();
     }
 }
 
@@ -1272,7 +1272,7 @@ void TapeDriveNode::slotTapeModified( Tape* tape )
     setText( tape->getName() );
 
     if ( owner->getCurrentItem() == this ) {
-        KDat::instance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
+        KDat::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
     }
 
     if ( ( childCount() == 0 ) && ( !isExpanded() ) ) {
@@ -1454,12 +1454,12 @@ bool BackupProfileNode::isType( int type )
 
 void BackupProfileNode::selected()
 {
-    KDat::instance()->showBackupProfileInfo( _backupProfile );
+    KDat::getInstance()->showBackupProfileInfo( _backupProfile );
 }
 
 void BackupProfileNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupBackupProfileMenu( p );
+    KDat::getInstance()->popupBackupProfileMenu( p );
 }
 
 BackupProfileRootNode::BackupProfileRootNode()
@@ -1488,7 +1488,7 @@ void BackupProfileRootNode::setSelected( BackupProfile* pBackupProfile )
         pNode->selected();
     }
 
-    KDat::instance()->configureUI( TapeManager::instance()->getMountedTape() );
+    KDat::getInstance()->configureUI( TapeManager::instance()->getMountedTape() );
 }
 
 bool BackupProfileRootNode::isType( int type )
@@ -1529,7 +1529,7 @@ void BackupProfileRootNode::collapsed()
 
 void BackupProfileRootNode::popupMenu( const QPoint& p )
 {
-    KDat::instance()->popupBackupProfileRootMenu( p );
+    KDat::getInstance()->popupBackupProfileRootMenu( p );
 }
 
 void BackupProfileRootNode::slotBackupProfileAdded( BackupProfile* backupProfile )
