@@ -17,23 +17,25 @@
 
 #include <stdlib.h>
 
-#include <qchkbox.h>
-#include <qcombo.h>
-#include <qgrpbox.h>
+#include <qcheckbox.h>
+#include <qcombobox.h>
+#include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlined.h>
-#include <qpushbt.h>
+#include <qlineedit.h>
+#include <qpushbutton.h>
 
 #include <kapp.h>
 #include <kfiledialog.h>
+#include <kmessagebox.h>
 
 #include "Options.h"
 #include "OptionsDlg.h"
+#include <klocale.h>
 
 #include "OptionsDlg.moc"
 
-OptionsDlg::OptionsDlg( QWidget* parent, const char* name = 0 )
+OptionsDlg::OptionsDlg( QWidget* parent, const char* name )
         : QDialog( parent, name, TRUE )
 {
     setCaption( i18n( "KDat: Options" ) );
@@ -193,19 +195,35 @@ OptionsDlg::~OptionsDlg()
 
 void OptionsDlg::slotBrowseTapeDevice()
 {
-    QString tmp;
-    tmp = KFileDialog::getOpenFileName( _tapeDevice->text() );
-    if ( tmp.length() ) {
-        _tapeDevice->setText( tmp );
+    KURL url;
+    url = KFileDialog::getOpenURL( _tapeDevice->text() );
+    
+    if( !url.isLocalFile() )
+    {
+      KMessageBox::sorry( 0L, i18n( "Only local files are supported" ) );
+      return;
+    }
+    
+    if ( !url.isEmpty() )
+    {
+        _tapeDevice->setText( url.path() );
     }
 }
 
 void OptionsDlg::slotBrowseTarCommand()
 {
-    QString tmp;
-    tmp = KFileDialog::getOpenFileName( _tarCommand->text() );
-    if ( tmp.length() ) {
-        _tarCommand->setText( tmp );
+    KURL url;
+    url = KFileDialog::getOpenURL( _tarCommand->text() );
+    
+    if( !url.isLocalFile() )
+    {
+      KMessageBox::sorry( 0L, i18n( "Only local files supported yet" ) );
+      return;
+    }
+    
+    if ( !url.isEmpty() )
+    {
+        _tarCommand->setText( url.path() );
     }
 }
 
