@@ -20,8 +20,12 @@
 #include <time.h>
 #include <unistd.h>
 
+#include <qfile.h>
+#include <qmessagebox.h>
+
+#include <klocale.h>
+#include <kstddirs.h>
 #include <kapp.h>
-#include <kmsgbox.h>
 
 #include "IndexDlg.h"
 #include "KDat.h"
@@ -37,12 +41,12 @@ Tape::Tape()
           _size( Options::instance()->getDefaultTapeSize() ),
           _fptr( 0 )
 {
-    _id.resize( 1024 );
-    gethostname( _id.data(), 1024 );
+    char buffer[1024];
+    gethostname( buffer, 1024 );
     time_t tm = time( NULL );
     _ctime = tm;
     _mtime = tm;
-    _id.sprintf( "%s:%d", _id.data(), tm );
+    _id.sprintf( "%s:%d", buffer, tm );
 
     write();
 }
@@ -67,13 +71,13 @@ void Tape::format()
 {
     // Rewind tape.
     if ( !TapeDrive::instance()->rewind() ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Format Failed" ), i18n( "Rewinding tape failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Rewinding tape failed." ), i18n("OK"));
         return;
     }
 
     // Set block size for tape.
     if ( !TapeDrive::instance()->setBlockSize( Options::instance()->getTapeBlockSize() ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Format Failed" ), i18n( "Cannot set tape block size." ), KMsgBox::EXCLAMATION );
+        QMessageBox::information( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Cannot set tape block size." ), i18n("OK") );
         return;
     }
 
@@ -82,25 +86,25 @@ void Tape::format()
 
     // KDat magic string.
     if ( TapeDrive::instance()->write( KDAT_MAGIC, KDAT_MAGIC_LENGTH ) < KDAT_MAGIC_LENGTH ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Format Failed" ), i18n( "Writing magic string failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::information( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing magic string failed." ), i18n("OK") );
         return;
     }
     
     // Tape header version number.
     iv = KDAT_TAPE_HEADER_VERSION;
     if ( TapeDrive::instance()->write( (const char*)&iv, 4 ) < 4 ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Format Failed" ), i18n( "Writing version number failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing version number failed." ), i18n("OK") );
         return;
     }
 
     // Write tape ID.  Tape ID is machine name + current time.
     iv = _id.length() + 1;
     if ( TapeDrive::instance()->write( (const char*)&iv, 4 ) < 4 ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Format Failed" ), i18n( "Writing tape ID length failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing tape ID length failed." ), i18n("OK") );
         return;
     }
     if ( TapeDrive::instance()->write( _id.data(), iv ) < iv ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Format Failed" ), i18n( "Writing tape ID failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing tape ID failed." ), i18n("OK") );
         return;
     }
 
@@ -121,18 +125,17 @@ void Tape::read()
     _stubbed = FALSE;
 
     if ( !_fptr ) {
-        QString fn = getenv( "HOME" );
-        fn += "/.kdat/";
-        fn += _id;
-        _fptr = fopen( fn.data(), "r+" );
+        QString filename = locateLocal( "appdata", _id);
+    
+        _fptr = fopen( QFile::encodeName(filename), "r" );
     }
 
     if ( !_fptr ) {
         // No tape index file was found.
-        if ( KMsgBox::yesNo( KDat::instance(), i18n( "KDat: Tape Index" ), i18n( "No index file was found for this tape.\nRecreate the index from tape?" ), KMsgBox::EXCLAMATION ) == 1 ) {
+        if ( QMessageBox::information( KDat::getInstance(), i18n( "KDat: Tape Index" ), i18n( "No index file was found for this tape.\nRecreate the index from tape?" ), i18n("OK") ) == 0 ) {
             write();
             
-            IndexDlg dlg( this, KDat::instance() );
+            IndexDlg dlg( this, KDat::getInstance() );
             dlg.exec();
             TapeManager::instance()->addTape( this );
             return;
@@ -147,7 +150,7 @@ void Tape::read()
 
     // Read index file version number.
     if ( !fgets( buf, 4096, _fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading version number failed." ), KMsgBox::EXCLAMATION );
+      QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading version number failed." ), i18n("OK") );
         fclose( _fptr );
         return;
     }
@@ -189,7 +192,7 @@ void Tape::read()
         {
             QString msg;
             msg.sprintf( i18n( "The tape index file format is version %d.  The index cannot be read by this version of KDat.  Perhaps the tape index file was created by a newer version of KDat?" ), version );
-            KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), msg, KMsgBox::EXCLAMATION );
+            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), msg, i18n("OK") );
         }
     }
 }
@@ -206,19 +209,18 @@ void Tape::readAll( int version )
 
 void Tape::write()
 {
-    QString fn = getenv( "HOME" );
-    fn += "/.kdat/";
-    fn += _id;
+    QString filename = locateLocal( "appdata", _id);
+    
     if ( !_fptr ) {
-        _fptr = fopen( fn.data(), "w" );
+        _fptr = fopen( QFile::encodeName(filename), "w" );
 
         if ( !_fptr ) {
             // Suck!
-            printf( "Tape::write() -- cannot open '%s' for writing!\n", fn.data() );
+            printf( "Tape::write() -- cannot open '%s' for writing!\n", filename.ascii() );
             return;
         }
     } else {
-        freopen( fn.data(), "w", _fptr );
+        freopen( QFile::encodeName(filename), "w", _fptr );
     }
     
     int zero = 0;
@@ -257,7 +259,7 @@ void Tape::write()
         i.current()->write( _fptr );
     }
 
-    freopen( fn.data(), "r+", _fptr );
+    freopen( QFile::encodeName(filename), "r+", _fptr );
 }
 
 QString Tape::getID()
@@ -420,11 +422,10 @@ void Tape::removeChild( Archive* archive )
         fseek( _fptr, MAX_NUM_ARCHIVES * 4, SEEK_CUR );
         here = ftell( _fptr );
     }
-    QString fn = getenv( "HOME" );
-    fn += "/.kdat/";
-    fn += _id;
-    truncate( fn.data(), here );
-    freopen( fn.data(), "r+", _fptr );
+
+    QString filename = locateLocal( "appdata", _id);
+    truncate( QFile::encodeName(filename), here );
+    freopen( QFile::encodeName(filename), "r+", _fptr );
     fflush( _fptr );
 
     setMTime( time( NULL ) );
@@ -450,11 +451,10 @@ void Tape::clear()
     fwrite( &ival, sizeof( ival ), 1, _fptr );
     fseek( _fptr, MAX_NUM_ARCHIVES * 4, SEEK_CUR );
     int here = ftell( _fptr );
-    QString fn = getenv( "HOME" );
-    fn += "/.kdat/";
-    fn += _id;
-    truncate( fn.data(), here );
-    freopen( fn.data(), "r+", _fptr );
+
+    QString filename = locateLocal( "appdata", _id);
+    truncate( QFile::encodeName(filename), here );
+    freopen( QFile::encodeName(filename), "r+", _fptr );
     fflush( _fptr );
 
     setMTime( time( NULL ) );
@@ -468,33 +468,33 @@ void Tape::readVersion1Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         return;
     }
     QString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
         return;
     }
 
     // Read creation time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading creation time failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading creation time failed." ), i18n("OK") );
         return;
     }
     _ctime = atoi( buf );
 
     // Read modification time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading modification time failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading modification time failed." ), i18n("OK") );
         return;
     }
     _mtime = atoi( buf );
 
     // Read tape name.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape name failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape name failed." ), i18n("OK") );
         return;
     }
     _name = buf;
@@ -502,14 +502,14 @@ void Tape::readVersion1Index( FILE* fptr )
 
     // Read tape size.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape size failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape size failed." ), i18n("OK") );
         return;
     }
     _size = atoi( buf );
 
     // Read number of archives.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive count failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive count failed." ), i18n("OK") );
         return;
     }
     int numArchives = atoi( buf );
@@ -517,7 +517,7 @@ void Tape::readVersion1Index( FILE* fptr )
     for ( ; numArchives; numArchives-- ) {
         // Read archive name.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive name failed." ), KMsgBox::EXCLAMATION );
+            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive name failed." ), i18n("OK") );
             return;
         }
         QString archiveName = buf;
@@ -525,21 +525,21 @@ void Tape::readVersion1Index( FILE* fptr )
 
         // Read archive time stamp.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive time stamp failed." ), KMsgBox::EXCLAMATION );
+            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive time stamp failed." ), i18n("OK") );
             return;
         }
         int archiveTimeStamp = atoi( buf );
 
         // Read archive start block.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive start block failed." ), KMsgBox::EXCLAMATION );
+            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive start block failed." ), i18n("OK") );
             return;
         }
         int archiveStartBlock = atoi( buf );
 
         // Read archive end block.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive end block failed." ), KMsgBox::EXCLAMATION );
+            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive end block failed." ), i18n("OK") );
             return;
         }
         int archiveEndBlock = atoi( buf );
@@ -552,7 +552,7 @@ void Tape::readVersion1Index( FILE* fptr )
         
         // Read the number of files.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive file count failed." ), KMsgBox::EXCLAMATION );
+            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive file count failed." ), i18n("OK") );
             return;
         }
         int archiveNumFiles = atoi( buf );
@@ -564,7 +564,7 @@ void Tape::readVersion1Index( FILE* fptr )
         for ( ; archiveNumFiles; archiveNumFiles-- ) {
             // Read file name.
             if ( !fgets( buf, 4096, fptr ) ) {
-                KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading file name failed." ), KMsgBox::EXCLAMATION );
+                QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading file name failed." ), i18n("OK") );
                 return;
             }
             QString fileName = buf;
@@ -572,21 +572,21 @@ void Tape::readVersion1Index( FILE* fptr )
             
             // Read file size.
             if ( !fgets( buf, 4096, fptr ) ) {
-                KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading file size failed." ), KMsgBox::EXCLAMATION );
+                QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading file size failed." ), i18n("OK") );
                 return;
             }
             int fileSize = atoi( buf );
             
             // Read file modification time.
             if ( !fgets( buf, 4096, fptr ) ) {
-                KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading file modification time failed." ), KMsgBox::EXCLAMATION );
+                QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading file modification time failed." ), i18n("OK") );
                 return;
             }
             int fileModTime = atoi( buf );
             
             // Read file record number.
             if ( !fgets( buf, 4096, fptr ) ) {
-                KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading file record number failed." ), KMsgBox::EXCLAMATION );
+                QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading file record number failed." ), i18n("OK") );
                 return;
             }
             int fileRecord = atoi( buf );
@@ -615,33 +615,33 @@ void Tape::readVersion2Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         return;
     }
     QString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
         return;
     }
     
     // Read creation time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading creation time failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading creation time failed." ), i18n("OK") );
         return;
     }
     _ctime = atoi( buf );
     
     // Read modification time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading modification time failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading modification time failed." ), i18n("OK") );
         return;
     }
     _mtime = atoi( buf );
     
     // Read tape name.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape name failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape name failed." ), i18n("OK") );
         return;
     }
     _name = buf;
@@ -649,14 +649,14 @@ void Tape::readVersion2Index( FILE* fptr )
     
     // Read tape size.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape size failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape size failed." ), i18n("OK") );
         return;
     }
     _size = atoi( buf );
     
     // Read number of archives.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive count failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive count failed." ), i18n("OK") );
         return;
     }
     int numArchives = atoi( buf );
@@ -672,17 +672,18 @@ void Tape::readVersion3Index( FILE* fptr )
 {
     fseek( fptr, 0, SEEK_CUR );
 
-    char buf[4096];
+    char buf[4097];
+    buf[4096] = '\0';
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         return;
     }
     QString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
         return;
     }
     
@@ -696,9 +697,9 @@ void Tape::readVersion3Index( FILE* fptr )
     fread( &_size, sizeof( _size ), 1, fptr );
     
     // Read tape name.
-    _name.resize( 4096 );
-    fread( _name.data(), sizeof( char ), 4096, fptr );
-    
+    fread( buf, sizeof( char ), 4096, fptr );
+    _name = buf;
+
     // Read number of archives.
     int numArchives;
     fread( &numArchives, sizeof( numArchives ), 1, fptr );
@@ -714,17 +715,18 @@ void Tape::readVersion4Index( FILE* fptr )
 {
     fseek( fptr, 0, SEEK_CUR );
 
-    char buf[4096];
+    char buf[4097];
+    buf[4096] = '\0';
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         return;
     }
     QString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
         return;
     }
     
@@ -738,8 +740,8 @@ void Tape::readVersion4Index( FILE* fptr )
     fread( &_size, sizeof( _size ), 1, fptr );
     
     // Read tape name.
-    _name.resize( 4096 );
-    fread( _name.data(), sizeof( char ), 4096, fptr );
+    fread( buf, sizeof( char ), 4096, fptr );
+    _name = buf;
     
     // Read number of archives.
     int numArchives;
