@@ -24,7 +24,6 @@
 #include <time.h>
 
 #include <kapp.h>
-#include <kmsgbox.h>
 
 #include "KDat.h"
 #include "Options.h"
@@ -32,6 +31,8 @@
 #include "TapeManager.h"
 #include "TapeDrive.h"
 #include "kdat.h"
+#include <klocale.h>
+#include <qmessagebox.h>
 
 #include "TapeDrive.moc"
 
@@ -219,7 +220,7 @@ Tape* TapeDrive::readHeader()
     // Rewind tape.
     emit sigStatus( "Rewinding tape..." );
     if ( !rewind() ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Error" ), i18n( "Rewinding tape failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Error" ), i18n( "Rewinding tape failed." ), i18n("OK") );
         return NULL;
     }
 
@@ -227,7 +228,7 @@ Tape* TapeDrive::readHeader()
     emit sigStatus( i18n( "Reading magic string..." ) );
     char magic[9];
     if ( read( magic, 9 ) < 9 ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Error" ), i18n( "Reading magic string failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::information( KDat::getInstance(), i18n( "KDat: Error" ), i18n( "Reading magic string failed." ), i18n("OK") );
         return NULL;
     }
     if ( strncmp( "KDatMAGIC", magic, 9 ) ) {
@@ -239,24 +240,24 @@ Tape* TapeDrive::readHeader()
     emit sigStatus( i18n( "Reading version number..." ) );
     int version;
     if ( read( (char*)&version, 4 ) < 4 ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Error" ), i18n( "Reading version number failed." ), KMsgBox::EXCLAMATION );
+      QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Error" ), i18n( "Reading version number failed." ), i18n("OK"));
         return NULL;
     }
 
     if ( version > KDAT_TAPE_HEADER_VERSION ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Warning" ), i18n( "Tape was formatted by a more recent version of KDat, consider upgrading." ), KMsgBox::INFORMATION );
+        QMessageBox::information( KDat::getInstance(), i18n( "KDat: Warning" ), i18n( "Tape was formatted by a more recent version of KDat, consider upgrading." ), i18n("OK") );
     }
 
     // Read tape ID.
     emit sigStatus( i18n( "Reading tape ID..." ) );
     int len;
     if ( read( (char*)&len, 4 ) < 4 ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Error" ), i18n( "Reading tape ID length failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Error" ), i18n( "Reading tape ID length failed." ), i18n("OK") );
         return NULL;
     }
     char* tapeID = new char[len];
     if ( read( tapeID, len ) < len ) {
-        KMsgBox::message( KDat::instance(), i18n( "KDat: Error" ), i18n( "Reading tape ID failed." ), KMsgBox::EXCLAMATION );
+        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         delete [] tapeID;
         return NULL;
     }
@@ -375,7 +376,7 @@ bool TapeDrive::nextRecord( int count )
 
     if ( !status ) {
         // Try reading count * TapeBlockSize bytes.
-        char buf[Options::instance()->getTapeBlockSize()];
+        char *buf = new char[Options::instance()->getTapeBlockSize()];
         int bytes = count * Options::instance()->getTapeBlockSize();
         int ret;
         while ( bytes > 0 ) {
@@ -386,6 +387,7 @@ bool TapeDrive::nextRecord( int count )
             }
             bytes -= ret;
         }
+        delete [] buf;
         status = TRUE;
     }
     return status;
@@ -578,9 +580,11 @@ bool TapeDrive::seek( int file, int tarBlock )
 
     // If tapeBlockSize > 512, we may need to skip some tar blocks.
 //    printf ( "TapeDrive::seek() -- skipping %d tar blocks.\n", tarBlock - tapeBlock * ( Options::instance()->getTapeBlockSize() / 512 ) );
-    char buf[ Options::instance()->getTapeBlockSize() ];
+    char *buf = new char[ Options::instance()->getTapeBlockSize() ];
     read( buf, 512 * ( tarBlock - tapeBlock * ( Options::instance()->getTapeBlockSize() / 512 ) ) );
 
+    delete [] buf;
+    
     return TRUE;
 }
 
