@@ -18,11 +18,11 @@
 #include <stdlib.h>
 #include <time.h>
 
-#include <qcombo.h>
+#include <qcombobox.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlined.h>
-#include <qpushbt.h>
+#include <qlineedit.h>
+#include <qpushbutton.h>
 
 #include <kapp.h>
 
@@ -30,6 +30,7 @@
 #include "Tape.h"
 #include "TapeInfoWidget.h"
 #include "Util.h"
+#include <klocale.h>
 
 #include "TapeInfoWidget.moc"
 
