@@ -16,19 +16,14 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <qstrlist.h>
+#include <kglobal.h>
+#include <klocale.h>
 
 #include "Util.h"
 
 QString Util::bytesToString( uint bytes )
 {
-    QString str;
-
-    str.setNum( bytes );
-    for ( int i = str.length() - 3; i > 0; i -= 3 ) {
-        str.insert( i, ',' );
-    }
-
-    return str;
+    return KGlobal::locale()->formatNumber(bytes, 0);
 }
 
 QString Util::kbytesToString( uint kbytes )
