@@ -22,7 +22,7 @@
 
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 
 #include <kapp.h>
 #include <kprocess.h>
@@ -32,9 +32,12 @@
 #include "VerifyDlg.h"
 #include "TapeDrive.h"
 #include "Util.h"
+#include <klocale.h>
+#include <stdio.h>
 
 #include "VerifyDlg.moc"
 
+
 VerifyDlg::VerifyDlg( const char* workingDir, int fileno, const RangeList& ranges,
                       bool restore, QWidget* parent, const char* name )
         : QDialog( parent, name, TRUE ),
@@ -232,7 +235,7 @@ void VerifyDlg::slotProcessExited( KProcess* )
 
 void VerifyDlg::slotStdout( KProcess*, char* buf, int len )
 {
-    QString data( len + 1 );
+    QString data;
     data.replace( 0, len, buf );
     data[len] = '\0';
     _leftover += data;
@@ -295,7 +298,7 @@ void VerifyDlg::timerEvent( QTimerEvent* )
 
     int bytesToRead;
     int count;
-    char buf[Options::instance()->getTapeBlockSize()];
+    char *buf = new char[Options::instance()->getTapeBlockSize()];
     QListIterator<Range> i( _ranges.getRanges() );
     for ( ; ( !_done ) && ( !_aborted ) && ( i.current() ); ++i ) {
         // Move to the beginning of the next range.
@@ -314,10 +317,11 @@ void VerifyDlg::timerEvent( QTimerEvent* )
             if ( count < 0 ) {
                 printf( i18n( "failed while reading tape data.\n" ) );
                 _proc->closeStdin();
+                delete [] buf;
                 return;
             }
 
-            while ( ( !_done ) && ( !_aborted ) && ( !_wroteStdin ) ) KApplication::getKApplication()->processEvents();
+            while ( ( !_done ) && ( !_aborted ) && ( !_wroteStdin ) ) KApplication::kApplication()->processEvents();
             if ( _done || _aborted ) {
                 break;
             }
@@ -331,7 +335,7 @@ void VerifyDlg::timerEvent( QTimerEvent* )
             if ( elapsed > oldElapsed )
             {
                 updateStats();
-                KApplication::getKApplication()->processEvents();
+                KApplication::kApplication()->processEvents();
                 if ( _done || _aborted ) {
                     break;
                 }
@@ -344,10 +348,11 @@ void VerifyDlg::timerEvent( QTimerEvent* )
     updateStats();
 
     // Send an EOF block to tar.
-    bzero( buf, Options::instance()->getTapeBlockSize() );
+    memset( buf, 0, Options::instance()->getTapeBlockSize() );
     _proc->writeStdin( buf, Options::instance()->getTapeBlockSize() );
     
     _proc->closeStdin();
+    delete [] buf;
 }
 
 void VerifyDlg::updateStats()
@@ -368,11 +373,11 @@ void VerifyDlg::updateStats()
     str.sprintf( i18n( "%02d:%02d:%02d" ), remain / 3600, remain / 60 % 60, remain % 60 );
     _timeRemaining->setText( str );
     
-    str.sprintf( i18n( "%s" ), Util::kbytesToString( (int)_totalKBytes ).data() );
+    str = Util::kbytesToString( (int)_totalKBytes );
     _kbytesRead->setText( str );
     
     if ( elapsed > 0 ) {
-        str.sprintf( i18n( "%s/min" ), Util::kbytesToString( (int)_totalKBytes * 60 / elapsed ).data() );
+        str = i18n( "%1/min" ).arg(Util::kbytesToString( (int)_totalKBytes * 60 / elapsed ) );
         _transferRate->setText( str );
     }
 }
