@@ -1,5 +1,5 @@
 /*
- * $Id: ktreeview.cpp,v 1.1.1.1 1998/10/06 09:01:02 kulow Exp $
+ * $Id: ktreeview.cpp,v 1.3 1999/03/10 22:17:27 bialas Exp $
  *
  * KTreeView implementation
  * 
@@ -24,10 +24,10 @@
 
 #include <ktreeview.h>
 #include "ktreeview.moc"
-#include <qapp.h>			/* used for QApplication::closingDown() */
+#include <qapplication.h>			/* used for QApplication::closingDown() */
 #include <qkeycode.h>			/* used for keyboard interface */
 #include <qpainter.h>			/* used to paint items */
-#include <qscrbar.h>
+#include <qscrollbar.h>
 #include <assert.h>
 
 /*
@@ -317,7 +317,7 @@ void KTreeViewItem::paintExpandButton(QPainter* p, int indent, int cellHeight) c
     int cellCenterY = cellHeight / 2;
 
     expandButton.setRect(parentLeaderX - 4, cellCenterY - 4, 9, 9);
-    p->setBrush(white);
+    p->setBrush(Qt::white);
     p->drawRect(expandButton);
     if (expanded) {
 	p->drawLine(parentLeaderX - 2, cellCenterY, 
@@ -328,16 +328,16 @@ void KTreeViewItem::paintExpandButton(QPainter* p, int indent, int cellHeight) c
 	p->drawLine(parentLeaderX, cellCenterY - 2, 
 		    parentLeaderX, cellCenterY + 2);
     }
-    p->setBrush(NoBrush);
+    p->setBrush(Qt::NoBrush);
 }
 
 // paint the highlight 
 void KTreeViewItem::paintHighlight(QPainter* p, int indent, const QColorGroup& colorGroup,
-				   bool hasFocus, GUIStyle style) const
+				   bool hasFocus, Qt::GUIStyle style) const
 {
     QColor fc;
-    if (style == WindowsStyle)
-	fc = darkBlue;			/* hardcoded in Qt */
+    if (style == Qt::WindowsStyle)
+	fc = Qt::darkBlue;			/* hardcoded in Qt */
     else
 	fc = colorGroup.text();
     QRect textRect = textBoundingRect(indent);
@@ -345,11 +345,11 @@ void KTreeViewItem::paintHighlight(QPainter* p, int indent, const QColorGroup& c
     textRect.coords(&l, &t, &r, &b);
     p->fillRect(textRect, fc);		/* draw highlight background */
     if (hasFocus) {
-	if(style == WindowsStyle) {	/* draw Windows style highlight */
+	if(style == Qt::WindowsStyle) {	/* draw Windows style highlight */
 	    textRect.setCoords(l - 1, t - 1, r + 1, b + 1);
-	    p->setPen(QPen(yellow, 0, DotLine));
+	    p->setPen(QPen(Qt::yellow, 0, Qt::DotLine));
 	    p->setBackgroundColor(fc);
-	    p->setBackgroundMode(OpaqueMode);
+	    p->setBackgroundMode(Qt::OpaqueMode);
 	    p->drawRect(textRect);
 	    textRect.setCoords(l - 2, t - 2, r + 2, b + 2);
 	    p->setPen(fc);
@@ -605,7 +605,7 @@ KTreeView::KTreeView(QWidget *parent,
 	setFrameStyle(QFrame::Panel | QFrame::Plain);
 	setLineWidth(1);
     }
-    setAcceptFocus(true);
+    // setAcceptFocus(true);
     treeRoot = new KTreeViewItem;
     treeRoot->setExpanded(true);
     treeRoot->owner = this;
