@@ -1,6 +1,6 @@
 /*
- * $Revision: 1.1.1.1 $
- * $Date: 1998/10/06 09:01:02 $
+ * $Revision: 1.3 $
+ * $Date: 1999/03/10 22:17:29 $
  * 
  * KTreeView class interface
  * 
@@ -29,7 +29,7 @@
 #include <qpixmap.h>			/* used in items */
 #include <qstack.h>			/* used to specify tree paths */
 #include <qstring.h>			/* used in items */
-#include <qtablevw.h>			/* base class for widget */
+#include <qtableview.h>			/* base class for widget */
 
 // use stack of strings to represent path information
 typedef QStack<QString> KPath;
@@ -242,7 +242,7 @@ protected:
      */
     virtual void paintHighlight(QPainter* p, int indent,
 			const QColorGroup& cg, bool hasFocus,
-			GUIStyle style) const;
+			Qt::GUIStyle style) const;
 
     /**
      * paints the item's text
