@@ -15,21 +15,35 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+#include <sys/stat.h>
 #include <sys/types.h>
 #include <fcntl.h>
 #include <unistd.h>
 
 #include <kapp.h>
+#include <qfile.h>
+#include <klocale.h>
+#include <kcmdlineargs.h>
 
+#include <kaboutdata.h>
+
+#include "kdat.h"
 #include "KDat.h"
 
-// No prototype for mkdir?!?
-extern "C" int mkdir( const char* path, int mode );
+static const char *description = 
+	I18N_NOOP("tar-based DAT archiver for KDE");
+
 
 int main( int argc, char** argv )
 {
-    KApplication app( argc, argv, "kdat" );
-
+  KAboutData aboutData( "kdat", I18N_NOOP("KDat"), 
+    KDAT_VERSION, description, KAboutData::License_GPL, 
+    "(c) 1999-2000, Sean Vyain");
+  KCmdLineArgs::init( argc, argv, &aboutData );
+  aboutData.addAuthor( "Sean Vyain", 0, "svyain@mail.tds.net");
+//  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+  KApplication app;
+  
     // Test for the existance of $HOME/.kdat
     QString fn = getenv( "HOME" );
     fn += "/.kdat";
@@ -38,12 +52,12 @@ int main( int argc, char** argv )
         mkdir( fn.data(), 0700 );
     }
 
-    app.setMainWidget( KDat::instance() );
+    app.setMainWidget( KDat::getInstance() );
 
-    if ( app.isRestored() && KTopLevelWidget::canBeRestored( 1 ) ) {
-        KDat::instance()->restore( 1 );
+    if ( app.isRestored() && KTMainWindow::canBeRestored( 1 ) ) {
+        KDat::getInstance()->restore( 1 );
     } else {
-        KDat::instance()->show();
+        KDat::getInstance()->show();
     }
 
     return app.exec();
