@@ -2,15 +2,15 @@
 #define _KU_GRPNAMEDLG_H
 
 #include <qdialog.h>
-#include <qpushbt.h>
-#include <qlined.h>
+#include <qpushbutton.h>
+#include <qlineedit.h>
 #include <qlayout.h>
 #include "kgroup.h"
 
 class grpnamedlg : public QDialog {
   Q_OBJECT
 public:
-  grpnamedlg(KGroup *agroup, QWidget* parent = NULL, const char* name = NULL);
+  grpnamedlg(KGroup &AGroup, QWidget* parent = NULL, const char* name = NULL);
   ~grpnamedlg();
 
 protected slots:
@@ -18,7 +18,7 @@ protected slots:
   void cancel();
 
 protected:
-  KGroup *group;
+  KGroup &group;
 
   QPushButton *pbOk;
   QPushButton *pbCancel;
