@@ -4,26 +4,18 @@
 #include <qvalidator.h>
 #include <qdatetm.h>
 
-#include <kstring.h>
-
 #include "kdatectl.h"
-#include "kdatectl.moc"
 #include "misc.h"
 
 KDateCtl::KDateCtl(QWidget *parent, const char *name,
                    const char *checktitle, const char *title,
                    long adate, long abase, int ax, int ay) {
-  QString tmp;
-
   x = ax; y = ay;
 
-  ksprintf(&tmp, "%s_day", name);
-  day = addLineEdit(parent, tmp, x, y+25, 30, 27, "");
-  ksprintf(&tmp,  "va_%s_day", name);
-  day->setValidator(new QIntValidator(1, 31, parent, name));
+  day = addLineEdit(parent, QString("%1_day").arg(name), x, y+25, 30, 27, "");
+  day->setValidator(new QIntValidator(1, 31, parent, QString("va_%1_day").arg(name)));
 
-  ksprintf(&tmp, "%s_month", name);
-  month = new KCombo(FALSE, parent, tmp);
+  month = new QComboBox(FALSE, parent, QString("%1_month").arg(name));
   month->clear();
   month->insertItem(i18n("January"));
   month->insertItem(i18n("February"));
@@ -40,25 +32,21 @@ KDateCtl::KDateCtl(QWidget *parent, const char *name,
 
   month->setGeometry(x+40, y+25, 100, 27);
 
-  ksprintf(&tmp,  "%s_year", name);
-  year = addLineEdit(parent, tmp, x+150, y+25, 50, 27, "");
-  ksprintf(&tmp,  "va_%s_year", name);
-  year->setValidator(new QIntValidator(1970, 2023, parent, name));
+  year = addLineEdit(parent, QString("%1_year").arg(name), x+150, y+25, 50, 27, "");
+  year->setValidator(new QIntValidator(1970, 2023, parent, QString("va_%1_year").arg(name)));
 
-  ksprintf(&tmp, "%s_isempty", name);
-  isempty = new QCheckBox(checktitle, parent, tmp);
+  isempty = new QCheckBox(checktitle, parent, QString("%1_isempty").arg(name));
   isempty->setGeometry(x, y, 200, 20); 
   isempty->setAutoResize(true);
 
-  ksprintf(&tmp, "%s_title", name);
-  label = addLabel(parent, tmp, x+210, y+25, 50, 27, title);
+  label = addLabel(parent, QString("%1_title").arg(name), x+210, y+25, 50, 27, title);
 
   QObject::connect(isempty, SIGNAL(toggled(bool)), this,
                             SLOT(isEmptyToggled(bool)));
-  QObject::connect(day, SIGNAL(textChanged(const char *)), this,
-                            SLOT(dayChanged(const char *)));
-  QObject::connect(year, SIGNAL(textChanged(const char *)), this,
-                            SLOT(yearChanged(const char *)));
+  QObject::connect(day, SIGNAL(textChanged(const QString &)), this,
+                            SLOT(dayChanged(const QString &)));
+  QObject::connect(year, SIGNAL(textChanged(const QString &)), this,
+                            SLOT(yearChanged(const QString &)));
   QObject::connect(month, SIGNAL(activated(int)), this,
                             SLOT(monthChanged(int)));
 
@@ -149,8 +137,8 @@ void KDateCtl::isEmptyToggled(bool) {
   emit textChanged();
 }
 
-void KDateCtl::dayChanged(const char *text) {
-  iday = atoi(text);
+void KDateCtl::dayChanged(const QString &text) {
+  iday = text.toInt();
   emit textChanged();
 }
 
@@ -159,8 +147,8 @@ void KDateCtl::monthChanged(int) {
   emit textChanged();
 }
 
-void KDateCtl::yearChanged(const char *text) {
-  iyear = atoi(text);
+void KDateCtl::yearChanged(const QString &text) {
+  iyear = text.toInt();
   emit textChanged();
 }
 
