@@ -3,12 +3,11 @@
 
 //#include "includes.h"
 #include <qobject.h>
-#include <qlined.h>
+#include <qlineedit.h>
 #include <qlabel.h>
-#include <qchkbox.h>
+#include <qcheckbox.h>
 #include <qfont.h>
-
-#include <kcombo.h>
+#include <qcombobox.h>
 
 class KDateCtl: public QObject
 {
@@ -32,7 +31,7 @@ protected:
   long base;
   
   QLineEdit *day;
-  KCombo *month;
+  QComboBox *month;
   QLineEdit *year;
   QCheckBox *isempty;
   QLabel *label;
@@ -41,9 +40,9 @@ protected:
 
 protected slots:
   void isEmptyToggled(bool);
-  void dayChanged(const char *text);
+  void dayChanged(const QString &text);
   void monthChanged(int);
-  void yearChanged(const char *);
+  void yearChanged(const QString &);
 
 signals:
   void textChanged();
