@@ -1,3 +1,5 @@
+#include "globals.h"
+
 #include <errno.h>
 #include <unistd.h>
 #include <sys/types.h>
@@ -9,21 +11,16 @@
 #include <string.h>
 #include <limits.h>
 
-#include <qstring.h>
-
-#include <kstring.h>
-
-#include <kmsgbox.h>
-
-#include "maindlg.h"
-#include "globals.h"
-#include "kgroup.h"
-#include "misc.h"
-
 #ifdef _KU_SHADOW
 #include <shadow.h>
 #endif
 
+#include <qstring.h>
+
+#include "kglobal_.h"
+#include "kgroup.h"
+#include "misc.h"
+
 #ifdef _KU_QUOTA
 #include "mnt.h"
 #include "quota.h"
@@ -37,11 +34,9 @@
 #define _KU_FIRST_GID 1001 
 #endif
 
-KGroup::KGroup() {
+KGroup::KGroup() : pwd("*") {
   u.setAutoDelete(TRUE);
-  name.setStr("");
-  pwd.setStr("*");
-  gid     = 0;
+  gid = 0;
 }
   
 KGroup::KGroup(KGroup *copy) {
@@ -57,26 +52,26 @@ KGroup::~KGroup() {
 }
 
 const QString &KGroup::getName() const {
-  return (name);
+  return name;
 }
 
 const QString &KGroup::getPwd() const {
-  return (pwd);
+  return pwd;
 }
 
-unsigned int KGroup::getGID() const {
-  return (gid);
+gid_t KGroup::getGID() const {
+  return gid;
 }
 
 void KGroup::setName(const QString &data) {
-  name.setStr(data);
+  name = data;
 }
 
 void KGroup::setPwd(const QString &data) {
-  pwd.setStr(data);
+  pwd = data;
 }
 
-void KGroup::setGID(unsigned int data) {
+void KGroup::setGID(gid_t data) {
   gid = data;
 }
 
@@ -103,11 +98,11 @@ bool KGroup::removeUser(const QString &name) {
 }
 
 uint KGroup::count() const {
-  return (u.count());
+  return u.count();
 }
 
 QString KGroup::user(uint i) {
-  return (*u.at(i));
+  return *u.at(i);
 }
 
 void KGroup::clear() {
@@ -141,8 +136,7 @@ bool KGroups::load() {
   FILE *fgrp = fopen(GROUP_FILE, "r");
   QString tmp;
   if (fgrp == 0) {
-    ksprintf(&tmp, i18n("Error opening %s for reading"), GROUP_FILE);
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Error opening %1 for reading").arg(GROUP_FILE));
     return FALSE;
   }
 
@@ -175,7 +169,6 @@ bool KGroups::load() {
 bool KGroups::save() {
   FILE *grp;
   QString tmpS;
-  QString tmpN;
   QString tmp;
 
   if (!g_saved) {
@@ -186,19 +179,21 @@ bool KGroups::save() {
   umask(0077);
 
   if ((grp = fopen(GROUP_FILE, "w")) == NULL) {
-    ksprintf(&tmp, i18n("Error opening %s for writing"), GROUP_FILE);
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Error opening %1 for writing").arg(GROUP_FILE));
     return FALSE;
   }
 
   for (unsigned int i=0; i<g.count(); i++) {
-    tmpN.setNum(g.at(i)->getGID());
-    tmpS = g.at(i)->getName()+':'+g.at(i)->getPwd()+':'+tmpN+':';
-    for (uint j=0; j<g.at(i)->count(); j++) {
+    KGroup *gr = g.at(i);
+    tmpS = QString("%1:%2:%3:")
+      .arg(gr->getName())
+      .arg(gr->getPwd())
+      .arg(gr->getGID());
+    for (uint j=0; j<gr->count(); j++) {
        if (j != 0)
 	 tmpS += ',';
 
-       tmpS += g.at(i)->user(j);
+       tmpS += gr->user(j);
     }
     tmpS += '\n';
     fputs(tmpS, grp);
@@ -210,40 +205,35 @@ bool KGroups::save() {
 
 #ifdef GRMKDB
   if (system(GRMKDB) != 0) {
-    err->addMsg("Unable to build group database", STOP);
+    err->addMsg(i18n("Unable to build group database"), STOP);
     return FALSE;
   }
 #endif
-  return (TRUE);
+  return TRUE;
 }
 
 KGroup *KGroups::lookup(const QString &name) {
   for (uint i = 0; i<g.count(); i++)
     if (g.at(i)->getName() == name)
-      return (g.at(i));
+      return g.at(i);
   return NULL;
 }
 
-KGroup *KGroups::lookup(unsigned int gid) {
+KGroup *KGroups::lookup(gid_t gid) {
   for (uint i = 0; i<g.count(); i++)
     if (g.at(i)->getGID() == gid)
-      return (g.at(i));
+      return g.at(i);
   return NULL;
 }
 
-int KGroups::first_free() {
-  uint i = 0;
-  uint t = _KU_FIRST_GID ;
+gid_t KGroups::first_free() {
+  gid_t t = _KU_FIRST_GID ;
 
-  for (t= _KU_FIRST_GID ; t<65534; t++) {
-    while ((i<count()) && (group(i)->getGID() != t))
-      i++;
+  for (t = _KU_FIRST_GID ; t<65534; t++)
+    if (lookup(t) == NULL)
+      return t;
 
-    if (i == count())
-      return (t);
-  }
-
-  err->addMsg(i18n("You have more than 65534 groups!?!? You have ran out of gid space!"), STOP);
+  err->addMsg(i18n("You have more than 65534 groups!?!? You have ran out of gid space!"));
   return (-1);
 }
 
@@ -251,16 +241,16 @@ KGroups::~KGroups() {
   g.clear();
 }
 
-KGroup *KGroups::group(uint num) {
-  return (g.at(num));
+KGroup *KGroups::operator[](uint num) {
+  return g.at(num);
 }
 
 KGroup *KGroups::first() {
-  return (g.first());
+  return g.first();
 }
 
 KGroup *KGroups::next() {
-  return (g.next());
+  return g.next();
 }
 
 void KGroups::add(KGroup *ku) {
@@ -272,5 +262,6 @@ void KGroups::del(KGroup *au) {
 }
 
 uint KGroups::count() const {
-	return g.count();
+  return g.count();
 }
+
