@@ -4,7 +4,10 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/file.h>
-#ifdef _SCO_DS
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+#ifdef HAVE_SYS_FCNTL_H
 #include <sys/fcntl.h>
 #endif
 #include <sys/stat.h>
@@ -23,20 +26,17 @@
 #include <signal.h>
 #endif
 
-#include <qstring.h>
-#include <qdir.h>
-
-#include <kmsgbox.h>
-#include <kstring.h>
-
-#include "maindlg.h"
-#include "kuser.h"
-#include "misc.h"
-
 #ifdef _KU_SHADOW
 #include <shadow.h>
 #endif
 
+#include <qstring.h>
+#include <qdir.h>
+
+#include "kglobal_.h"
+#include "kuser.h"
+#include "misc.h"
+
 #ifdef _KU_QUOTA
 #include "mnt.h"
 #include "quota.h"
@@ -52,29 +52,15 @@
 
 // class KUser
 
-KUser::KUser() {
-  p_name.setStr("");
-  p_pwd.setStr("*");
-  p_dir.setStr("");
-  p_shell.setStr("");
-  p_fname.setStr("");
+KUser::KUser() : p_pwd("*") {
 #ifdef __FreeBSD__
-  p_office.setStr("");
-  p_ophone.setStr("");
-  p_hphone.setStr("");
-  p_class.setStr("");
   p_change = 0;
   p_expire = 0;
-#else
-  p_office1.setStr("");
-  p_office2.setStr("");
-  p_address.setStr("");
 #endif
   p_uid     = 0;
   p_gid     = 100;
 
 #ifdef _KU_SHADOW   
-  s_pwd.setStr("");
   s_lstchg  = 0;
   s_min     = 0;
   s_max     = -1;
@@ -146,149 +132,149 @@ int KUser::getCopySkel() {
 }
 
 const QString &KUser::getName() const {
-  return (p_name);
+  return p_name;
 }
 
 const QString &KUser::getPwd() const {
-  return (p_pwd);
+  return p_pwd;
 }
 
 const QString &KUser::getHomeDir() const {
-  return (p_dir);
+  return p_dir;
 }
 
 const QString &KUser::getShell() const {
-  return (p_shell);
+  return p_shell;
 }
 
 const QString &KUser::getFullName() const {
-  return (p_fname);
+  return p_fname;
 }
 
 #ifdef __FreeBSD__
 // FreeBSD apparently uses the GECOS fields differently than other Unices.
 // Create some better named functions to make the FreeBSD code clear
 const QString &KUser::getOffice() const {
-  return (p_office);
+  return p_office;
 }
 
 const QString &KUser::getWorkPhone() const {
-  return (p_ophone);
+  return p_ophone;
 }
 
 const QString &KUser::getHomePhone() const {
-  return (p_hphone);
+  return p_hphone;
 }
 
 // New fields needed for the FreeBSD /etc/master.passwd file
 const QString &KUser::getClass() const {
-  return (p_class);
+  return p_class;
 }
 
 time_t KUser::getLastChange() const {
-  return (p_change);
+  return p_change;
 }
 
 time_t KUser::getExpire() const {
-  return (p_expire);
+  return p_expire;
 }
 
 #else
 
 const QString &KUser::getOffice1() const {
-  return (p_office1);
+  return p_office1;
 }
 
 const QString &KUser::getOffice2() const {
-  return (p_office2);
+  return p_office2;
 }
 
 const QString &KUser::getAddress() const {
-  return (p_address);
+  return p_address;
 }
 
 #endif
 
-unsigned int KUser::getUID() const {
-  return (p_uid);
+uid_t KUser::getUID() const {
+  return p_uid;
 }
 
-unsigned int KUser::getGID() const {
-  return (p_gid);
+gid_t KUser::getGID() const {
+  return p_gid;
 }
 
 #ifdef _KU_SHADOW
 const QString &KUser::getSPwd() const {
-  return (s_pwd);
+  return s_pwd;
 }
 
 long KUser::getLastChange() const {
-  return(s_lstchg);
+  return s_lstchg;
 }
 
 int KUser::getMin() const {
-  return (s_min);
+  return s_min;
 }
 
 int KUser::getMax() const {
-  return (s_max);
+  return s_max;
 }
 
 int KUser::getWarn() const {
-  return (s_warn);
+  return s_warn;
 }
 
 int KUser::getInactive() const {
-  return (s_inact);
+  return s_inact;
 }
 
 int KUser::getExpire() const {
-  return (s_expire);
+  return s_expire;
 }
 
 int KUser::getFlag() const {
-  return (s_flag);
+  return s_flag;
 }
 #endif
 
 void KUser::setName(const QString &data) {
-  p_name.setStr(data);
+  p_name = data;
 }
 
 void KUser::setPwd(const QString &data) {
-  p_pwd.setStr(data);
+  p_pwd = data;
 }
 
 void KUser::setHomeDir(const QString &data) {
-  p_dir.setStr(data);
+  p_dir = data;
 }
 
 void KUser::setShell(const QString &data) {
-  p_shell.setStr(data);
+  p_shell = data;
 }
 
 void KUser::setFullName(const QString &data) {
-  p_fname.setStr(data);
+  p_fname = data;
 }
 
 #ifdef __FreeBSD__
 // FreeBSD apparently uses the GECOS fields differently than other Unices.
 // Create some better named functions to make the FreeBSD code clear
 void KUser::setOffice(const QString &data) {
-  p_office.setStr(data);
+  p_office = data;
 }
 
 void KUser::setWorkPhone(const QString &data) {
-  p_ophone.setStr(data);
+  p_ophone = data;
 }
 
 void KUser::setHomePhone(const QString &data) {
-  p_hphone.setStr(data);
+  p_hphone = data;
 }
 
 // New fields needed for the FreeBSD /etc/master.passwd file
 void KUser::setClass(const QString &data) {
-  p_class.setStr(data);
+  p_class = data;
 }
 
 void KUser::setLastChange(time_t data) {
@@ -302,30 +288,30 @@ void KUser::setExpire(time_t data) {
 #else
 
 void KUser::setOffice1(const QString &data) {
-  p_office1.setStr(data);
+  p_office1 = data;
 }
 
 void KUser::setOffice2(const QString &data) {
-  p_office2.setStr(data);
+  p_office2 = data;
 }
 
 void KUser::setAddress(const QString &data) {
-  p_address.setStr(data);
+  p_address = data;
 }
 
 #endif
 
-void KUser::setUID(unsigned int data) {
+void KUser::setUID(uid_t data) {
   p_uid = data;
 }
 
-void KUser::setGID(unsigned int data) {
+void KUser::setGID(gid_t data) {
   p_gid = data;
 }
 
 #ifdef _KU_SHADOW
 void KUser::setSPwd(const QString &data) {
-  s_pwd.setStr(data);
+  s_pwd = data;
 }
 
 void KUser::setLastChange(long data) {
@@ -371,8 +357,8 @@ void KUser::setCopySkel(int data) {
 }
 
 KUsers::KUsers() {
-  p_backuped = 0;
-  s_backuped = 0;
+  p_backuped = FALSE;
+  s_backuped = FALSE;
 
   pwd_mode = 0644;
   pwd_uid = 0;
@@ -452,8 +438,7 @@ bool KUsers::loadpwd() {
 #ifdef HAVE_FGETPWENT
   FILE *fpwd = fopen(PASSWORD_FILE, "r");
   if(fpwd == NULL) {
-     ksprintf(&tmp, i18n("Error opening %s for reading"), PASSWORD_FILE);
-     err->addMsg(tmp, STOP);
+     err->addMsg(i18n("Error opening %1 for reading").arg(PASSWORD_FILE));
      return FALSE;
   }
 
@@ -461,9 +446,8 @@ bool KUsers::loadpwd() {
 #else
   while ((p = getpwent()) != NULL) {
 #endif
-
 #ifdef _KU_QUOTA
-    quotas->addQuota(p->pw_uid);
+    kug->getQuotas().addQuota(p->pw_uid);
 #endif
     tmpKU = new KUser();
     tmpKU->setUID(p->pw_uid);
@@ -524,9 +508,8 @@ bool KUsers::loadsdw() {
 
   while ((spw = getspent())) {     // read a shadow password structure
     if ((up = lookup(spw->sp_namp)) == NULL) {
-      ksprintf(&tmp, i18n("No /etc/passwd entry for %s.\nEntry will be removed at the next `Save'-operation."),
-                  spw->sp_namp);
-      err->addMsg(tmp, STOP);
+      err->addMsg(i18n("No /etc/passwd entry for %1.\nEntry will be removed at the next `Save'-operation.")
+		  .arg(spw->sp_namp));
       err->display();
       continue;
     }
@@ -619,8 +602,7 @@ bool KUsers::savepwd() {
   umask(0077);
 
   if ((passwd = fopen(PASSWORD_FILE,"w")) == NULL) {
-    ksprintf(&tmp, i18n("Error opening %s for writing"), PASSWORD_FILE);
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Error opening %1 for writing").arg(PASSWORD_FILE));
     return FALSE;
   }
 
@@ -628,23 +610,33 @@ bool KUsers::savepwd() {
     KUser *user = u.at(i);
 
 #ifdef __FreeBSD__
-    ksprintf(&s, "%s:%s:%i:%i:%s:%i:%i:", (const char *)user->getName(),
-             (const char *)user->getPwd(), user->getUID(),
-             user->getGID(), (const char *)user->getClass(),
-             user->getLastChange(), user->getExpire());
+    s = QString("%1:%2:%3:%4:%5:%6:%7:")
+        .arg(user->getName())
+        .arg(user->getPwd())
+	.arg(user->getUID())
+        .arg(user->getGID())
+	.arg(user->getClass())
+        .arg(user->getLastChange())
+	.arg(user->getExpire());
 
-    ksprintf(&s1, "%s,%s,%s,%s", (const char *)user->getFullName(),
-              (const char *)user->getOffice(),
-              (const char *)user->getWorkPhone(),
-              (const char *)user->getHomePhone());
+    s1 = QString("%1,%2,%3,%4")
+         .arg(user->getFullName())
+         .arg(user->getOffice())
+         .arg(user->getWorkPhone())
+         .arg(user->getHomePhone());
 #else
 
-    ksprintf(&s, "%s:%s:%i:%i:",  (const char *)user->getName(),
-             (const char *)user->getPwd(), (const char *)user->getUID(),
-             (const char *)user->getGID());
+    s = QString("%1:%2:%3:%4:")
+        .arg(user->getName())
+        .arg(user->getPwd())
+	.arg(user->getUID())
+        .arg(user->getGID());
 
-    ksprintf(&s1, "%s,%s,%s,%s", (const char *)user->getFullName(), (const char *)user->getOffice1(),
-	           (const char *)user->getOffice2(), (const char *)user->getAddress());
+    s1 = QString("%1,%2,%3,%4")
+         .arg(user->getFullName())
+	 .arg(user->getOffice1())
+	 .arg(user->getOffice2())
+	 .arg(user->getAddress());
 
 #endif
 
@@ -655,7 +647,7 @@ bool KUsers::savepwd() {
       s1.truncate(j);
     }
 
-    s+=s1+":"+user->getHomeDir()+":"+user->getShell()+"\n";
+    s += s1+":"+user->getHomeDir()+":"+user->getShell()+"\n";
     fputs((const char *)s, passwd);
   }
   fclose(passwd);
@@ -667,8 +659,7 @@ bool KUsers::savepwd() {
   // need to run a utility program to build /etc/passwd, /etc/pwd.db
   // and /etc/spwd.db from /etc/master.passwd
   if (system(PWMKDB) != 0) {
-     ksprintf(&tmp, i18n("Unable to build password database"));
-     err->addMsg(tmp, STOP);
+     err->addMsg(i18n("Unable to build password database"), STOP);
      return FALSE;
   }
 #endif
@@ -697,8 +688,7 @@ bool KUsers::savesdw() {
   umask(0077);
 
   if ((f = fopen(SHADOW_FILE, "w")) == NULL) {
-    ksprintf(&tmp, i18n("Error opening %s for writing"), SHADOW_FILE);
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Error opening %1 for writing").arg(SHADOW_FILE));
     return FALSE;
   }
 
@@ -708,8 +698,7 @@ bool KUsers::savesdw() {
   for (uint index = 0; index < u.count(); index++) {
     up = u.at(index);
     if (!(const char *)up->getSPwd()) {
-      ksprintf(&tmp, i18n("No shadow entry for %s."), (const char *)up->getName());
-      err->addMsg(tmp, STOP);
+      err->addMsg(i18n("No shadow entry for %1.").arg(up->getName()));
       continue;
     }
 
@@ -745,27 +734,21 @@ KUser *KUsers::lookup(const char *name) {
   return NULL;
 }
 
-KUser *KUsers::lookup(unsigned int uid) {
+KUser *KUsers::lookup(uid_t uid) {
   for (uint i = 0; i<u.count(); i++)
     if (u.at(i)->getUID() == uid)
       return (u.at(i));
   return NULL;
 }
 
-int KUsers::first_free() {
-  uint i = 0;
-  uint t = _KU_FIRST_UID ;
+uid_t KUsers::first_free() {
+  uid_t t = _KU_FIRST_UID ;
 
-  for (t = _KU_FIRST_UID ; t<65534; t++) {
-    while ((i<u.count()) && (u.at(i)->getUID() != t))
-      i++;
+  for (t = _KU_FIRST_UID ; t<65534; t++)
+    if (lookup(t) == NULL)
+      return t;
 
-    if (i == u.count())
-      return (t);
-    i = 0;
-  }
-
-  err->addMsg(i18n("You have more than 65534 users!?!? You have ran out of uid space!"), STOP);
+  err->addMsg(i18n("You have more than 65534 users!?!? You have ran out of uid space!"));
   return (-1);
 }
 
@@ -775,19 +758,19 @@ KUsers::~KUsers() {
 }
 
 uint KUsers::count() const {
-  return (u.count());
+  return u.count();
 }
 
-KUser *KUsers::user(uint num) {
-  return (u.at(num));
+KUser *KUsers::operator[](uint num) {
+  return u.at(num);
 }
 
 KUser *KUsers::first() {
-  return (u.first());
+  return u.first();
 }
 
 KUser *KUsers::next() {
-  return (u.next());
+  return u.next();
 }
 
 void KUsers::add(KUser *ku) {
@@ -804,30 +787,22 @@ void KUser::createHome() {
   QDir d = QDir::root();
 
   if (d.cd(p_dir)) {
-    QString tmp;
-    ksprintf(&tmp, i18n("Directory %s already exists"), (const char *)p_dir);
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Directory %1 already exists").arg(p_dir));
     err->display();
   }
 
   if (mkdir((const char *)p_dir, 0700) != 0) {
-    QString tmp;
-    ksprintf(&tmp, i18n("Cannot create home directory\nError: %s"), strerror(errno));
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Cannot create home directory\nError: %1").arg(strerror(errno)));
     err->display();
   }
 
   if (chown((const char *)p_dir, p_uid, p_gid) != 0) {
-    QString tmp;
-    ksprintf(&tmp, i18n("Cannot change owner of home directory\nError: %s"), strerror(errno));
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Cannot change owner of home directory\nError: %1").arg(strerror(errno)));
     err->display();
   }
 
   if (chmod((const char *)p_dir, KU_HOMEDIR_PERM) != 0) {
-    QString tmp;
-    ksprintf(&tmp, i18n("Cannot change permissions on home directory\nError: %s"), strerror(errno));
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Cannot change permissions on home directory\nError: %1").arg(strerror(errno)));
     err->display();
   }
 }
@@ -835,13 +810,12 @@ void KUser::createHome() {
 int KUser::createMailBox() {
   QString mailboxpath;
   int fd;
-  ksprintf(&mailboxpath, "%s/%s", MAIL_SPOOL_DIR, (const char *)p_name);
+  mailboxpath = QString("%1/%2").arg(MAIL_SPOOL_DIR).arg(p_name);
   if((fd = open((const char *)mailboxpath, O_CREAT|O_EXCL|O_WRONLY,
                 S_IRUSR|S_IWUSR)) < 0) {
-    QString tmp;
-    ksprintf(&tmp, "Cannot create %s: %s", (const char *)mailboxpath,
-             strerror(errno));
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Cannot create %1: %2")
+                .arg(mailboxpath)
+                .arg(strerror(errno)));
     err->display();
     return -1;
   }
@@ -849,19 +823,15 @@ int KUser::createMailBox() {
   close(fd);
 
   if (chown((const char *)mailboxpath, p_uid, KU_MAILBOX_GID) != 0) {
-    QString tmp;
-    ksprintf(&tmp, "Cannot change owner on mailbox: %s\nError: %s",
-             (const char *)mailboxpath, strerror(errno));
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Cannot change owner on mailbox: %1\nError: %2")
+                .arg(mailboxpath).arg(strerror(errno)));
     err->display();
     return -1;
   }
 
   if (chmod((const char *)mailboxpath, KU_MAILBOX_PERM) != 0) {
-    QString tmp;
-    ksprintf(&tmp, i18n("Cannot change permissions on mailbox: %s\nError: %s"),
-             (const char *)mailboxpath, strerror(errno));
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Cannot change permissions on mailbox: %1\nError: %2")
+                .arg(mailboxpath).arg(strerror(errno)));
     err->display();
   }
 
@@ -896,16 +866,14 @@ void KUser::copyDir(const QString &srcPath, const QString &dstPath) {
 
     d.mkdir(name, FALSE);
     if (chown(d.filePath(name), p_uid, p_gid) != 0) {
-      QString tmp;
-      ksprintf(&tmp, i18n("Cannot change owner of directory %s\nError: %s"), (const char *)d.filePath(s[i]), strerror(errno));
-      err->addMsg(tmp, STOP);
+      err->addMsg(i18n("Cannot change owner of directory %1\nError: %2")
+                  .arg(d.filePath(s[i])).arg(strerror(errno)));
       err->display();
     }
 
     if (chmod(d.filePath(name), st.st_mode & 07777) != 0) {
-      QString tmp;
-      ksprintf(&tmp, i18n("Cannot change permissions on directory %s\nError: %s"), (const char *)d.filePath(s[i]), strerror(errno));
-      err->addMsg(tmp, STOP);
+      err->addMsg(i18n("Cannot change permissions on directory %1\nError: %2")
+                  .arg(d.filePath(s[i])).arg(strerror(errno)));
       err->display();
     }
 
@@ -930,16 +898,14 @@ void KUser::copyDir(const QString &srcPath, const QString &dstPath) {
     }
 
     if (chown(d.filePath(name), p_uid, p_gid) != 0) {
-      QString tmp;
-      ksprintf(&tmp, i18n("Cannot change owner of file %s\nError: %s"), (const char *)d.filePath(s[i]), strerror(errno));
-      err->addMsg(tmp, STOP);
+      err->addMsg(i18n("Cannot change owner of file %1\nError: %2")
+                  .arg(d.filePath(s[i])).arg(strerror(errno)));
       err->display();
     }
 
     if (chmod(d.filePath(name), st.st_mode & 07777) != 0) {
-      QString tmp;
-      ksprintf(&tmp, i18n("Cannot change permissions on file %s\nError: %s"), (const char *)d.filePath(s[i]), strerror(errno));
-      err->addMsg(tmp, STOP);
+      err->addMsg(i18n("Cannot change permissions on file %1\nError: %2")
+                  .arg(d.filePath(s[i])).arg(strerror(errno)));
       err->display();
     }
   }
@@ -952,16 +918,13 @@ int KUser::copySkel() {
   umask(0777);
 
   if (!s.exists()) {
-    QString tmp;
-    ksprintf(&tmp, i18n("Directory %s does not exist"), (const char *)s.dirName());
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Directory %1 does not exist").arg(s.dirName()));
     err->display();
     return (-1);
   }
 
   if (!d.exists()) {
-    QString tmp;
-    ksprintf(&tmp, i18n("Directory %s does not exist"), (const char *)d.dirName());    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Directory %1 does not exist").arg(d.dirName()));
     err->display();
     return (-1);
   }
@@ -972,8 +935,8 @@ int KUser::copySkel() {
 }
 
 // Temporarily use rm
-// TODO: replace by our own procedure cause calling other programs
-//       for things we are know how to do is not a good idea
+//TODO: replace by our own procedure cause calling other programs
+//      for things we are know how to do is not a good idea
 
 int KUser::removeHome() {
   struct stat sb;
@@ -982,15 +945,13 @@ int KUser::removeHome() {
   if (!stat((const char *)p_dir, &sb))
     if (S_ISDIR(sb.st_mode) && sb.st_uid == p_uid) {
 #ifdef MINIX
-      ksprintf(&command, "/usr/bin/rm -rf -- %s", (const char *)p_dir);
+      command = QString("/usr/bin/rm -rf -- %1").arg(p_dir);
 #else
-      ksprintf(&command, "/bin/rm -rf -- %s", (const char *)p_dir);
+      command = QString("/bin/rm -rf -- %1").arg(p_dir);
 #endif
     if (system((const char *)command) != 0) {
-      QString tmp;
-      ksprintf(&tmp, i18n("Cannot remove home directory %s\nError: %s"),
-               (const char *)command, strerror(errno));
-      err->addMsg(tmp, STOP);
+      err->addMsg(i18n("Cannot remove home directory %1\nError: %2")
+                  .arg(command).arg(strerror(errno)));
       err->display();
      }
    }
@@ -998,22 +959,18 @@ int KUser::removeHome() {
   return 0;
 }
 
-// TODO: remove at jobs too.
+//TODO: remove at jobs too.
 
 int KUser::removeCrontabs() {
   QString file;
   QString command;
 
-  ksprintf(&file, "/var/cron/tabs/%s",
-           (const char*)p_name);
+  file = QString("/var/cron/tabs/%1").arg(p_name);
   if (access((const char *)file, F_OK) == 0) {
-  	ksprintf(&command, "crontab -u %s -r",
-             (const char*)p_name);
+    command = QString("crontab -u %1 -r").arg(p_name);
     if (system((const char *)command) != 0) {
-      QString tmp;
-      ksprintf(&tmp, i18n("Cannot remove crontab %s\nError: %s"),
-               (const char *)command, strerror(errno));
-      err->addMsg(tmp, STOP);
+      err->addMsg(i18n("Cannot remove crontab %1\nError: %2")
+                  .arg(command).arg(strerror(errno)));
       err->display();
      }
   }
@@ -1024,13 +981,10 @@ int KUser::removeCrontabs() {
 int KUser::removeMailBox() {
   QString file;
 
-  ksprintf(&file, "%s/%s", MAIL_SPOOL_DIR,
-           (const char*)p_name);
+  file = QString("%1/%2").arg(MAIL_SPOOL_DIR).arg(p_name);
   if (remove((const char *)file) != 0) {
-    QString tmp;
-    ksprintf(&tmp, i18n("Cannot remove mailbox %s\nError: %s"),
-             (const char *)file, strerror(errno));
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Cannot remove mailbox %1\nError: %2")
+                .arg(file).arg(strerror(errno)));
     err->display();
   }
 
@@ -1048,7 +1002,7 @@ int KUser::removeProcesses() {
         _exit(0);
         break;
       case -1:
-        err->addMsg(i18n("Cannot fork()"), STOP);
+        err->addMsg(i18n("Cannot fork()"));
         err->display();
         perror("fork");
         break;
