@@ -1,17 +1,10 @@
-// $Id: misc.cpp,v 1.15.2.2 1999/06/29 06:48:55 garbanzo Exp $
+// $Id: misc.cpp,v 1.22 2000/04/02 21:37:46 jansen Exp $
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <sys/types.h>
+#include "globals.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
-
-#include "globals.h"
-
 #include <unistd.h>
 
 #ifdef HAVE_MNTENT_H
@@ -27,10 +20,11 @@
 #include <sys/mnttab.h>
 #endif
 
-#include <kmsgbox.h>
+#include <qfile.h>
+#include <qmessagebox.h>
+
 #include "misc.h"
-#include "globals.h"
-#include "maindlg.h"
+#include "kglobal_.h"
 
 QString readentry(const QString &name, const QString def) {
   if (config->hasKey(name))
@@ -46,17 +40,19 @@ int readnumentry(const QString &name) {
     return (0);
 }
 
-void backup(char const *name) {
+void backup(char const *name)
+{
   char tmp[1024];
 
   sprintf(tmp, "%s%s", name, KU_BACKUP_EXT);
   unlink(tmp);
 
-  if (rename(name, tmp) == -1) {
-    sprintf(tmp, i18n("Can't create backup file for %s"), name);
-    err->addMsg(tmp, STOP);
-    err->display();
-    return;
+  if (rename(name, tmp) == -1)
+  {
+    QString str;
+    str = i18n("Can't create backup file for %1").arg(name);
+    QMessageBox::critical(0, i18n("Error"), tmp, i18n("OK"));
+    exit (1);
   }
 }
 
@@ -65,17 +61,16 @@ char *convertdate(char *buf, const long int base, const long int days) {
 
   tm *t;
 
-  if ((base+days)<24855l)
+  if ((base+days)<24855l) {
     if (days >0) {
       tmpd = (base+days)*24*60*60;
       t = localtime(&tmpd);
 
       sprintf(buf, "%d %d %d", t->tm_mday, t->tm_mon+1, t->tm_year+1900);
-    }
-    else {
+    } else {
       strcpy(buf, "Nothing");
     }
-  else {
+  } else {
     strcpy(buf, "Never");
   }
 
@@ -116,39 +111,36 @@ int getValue(long int &data, const char *text, const char *msg) {
   char *check;
   long int value = strtol(text, &check, 0);
   if (check[0]) {
-    err->addMsg(msg, STOP);
-    err->display();
+    QMessageBox::warning(0, i18n("Error"), msg, i18n("OK"));
     return (-1);
   }
   data = value;
 
-  return 0;
+  return (0);
 }
 
 int getValue(int &data, const char *text, const char *msg) {
   char *check;
   long int value = strtol(text, &check, 0);
   if (check[0]) {
-    err->addMsg(msg, STOP);
-    err->display();
+    QMessageBox::warning(0, i18n("Error"), msg, i18n("OK"));
     return (-1);
   }
   data = (int)value;
 
-  return 0;
+  return (0);
 }
 
 int getValue(unsigned int &data, const char *text, const char *msg) {
   char *check;
   long int value = strtol(text, &check, 0);
   if (check[0]) {
-    err->addMsg(msg, STOP);
-    err->display();
+    QMessageBox::warning(0, i18n("Error"), msg, i18n("OK"));
     return (-1);
   }
   data = (unsigned int)value;
 
-  return 0;
+  return (0);
 }
 
 int copyFile(QString from, QString to) {
@@ -164,36 +156,27 @@ int copyFile(QString from, QString to) {
   fo.setName(to);
   
   if (!fi.exists()) {
-    QString tmp;
-    
-    tmp.sprintf(i18n("File %s does not exist."), (const char *)from);
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("File %1 does not exist.").arg(from));
     return (-1);
   }
 
   if (!fi.open(IO_ReadOnly)) {
-    QString tmp;
-    
-    tmp.sprintf(i18n("Can not open file %s for reading."), (const char *)from);
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Can not open file %1 for reading.").arg(from));
     return (-1);
   }
     
   if (!fo.open(IO_Raw | IO_WriteOnly | IO_Truncate)) {
-    QString tmp;
-    
-    tmp.sprintf(i18n("Can not open file %s for writing."), (const char *)to);
-    err->addMsg(tmp, STOP);
+    err->addMsg(i18n("Can not open file %1 for writing.").arg(to));
     return (-1);
   }
   
   while (!fi.atEnd()) {
-    int len = fi.readBlock(buf, 4096);
+    int len = fi.readBlock(buf, 65536);
     fo.writeBlock(buf, len);
   }
   
   fi.close();
   fo.close();
     
-  return 0;
+  return (0);
 }
