@@ -1,60 +1,63 @@
 #ifdef _KU_QUOTA
 #include <stdlib.h>
 #include <stdio.h>
-#include "mnt.h"
-#include "quota.h"
 
-MntEnt::MntEnt(const char *afsname, const char *adir,
-               const char *atype, const char *aopts,
-               const char *aquotafilename){
-    fsname.setStr(afsname);
-    dir.setStr(adir);
-    type.setStr(atype);
-    opts.setStr(aopts);
-    quotafilename.setStr(aquotafilename);
+#include "mnt.h"
+#include "kuqconf.h"
+
+#include <qfile.h>
+
+MntEnt::MntEnt(const QString &afsname, const QString &adir,
+               const QString &atype, const QString &aopts,
+               const QString &aquotafilename){
+    fsname = afsname;
+    dir    = adir;
+    type   = atype;
+    opts   = aopts;
+    quotafilename = aquotafilename;
 }
 
 MntEnt::~MntEnt() {
 }
 
-QString MntEnt::getfsname() {
-  return (fsname);
+const QString &MntEnt::getfsname() const {
+  return fsname;
 }
 
-QString MntEnt::getdir() {
-  return (dir);
+const QString &MntEnt::getdir() const {
+  return dir;
 }
 
-QString MntEnt::gettype() {
-  return (type);
+const QString &MntEnt::gettype() const {
+  return type;
 }
 
-QString MntEnt::getopts() {
-  return (opts);
+const QString &MntEnt::getopts() const {
+  return opts;
 }
 
-QString MntEnt::getquotafilename() {
-  return (quotafilename);
+const QString &MntEnt::getquotafilename() const {
+  return quotafilename;
 }
 
-void MntEnt::setfsname(const char *data) {
-  fsname.setStr(data);
+void MntEnt::setfsname(const QString &data) {
+  fsname = data;
 }
 
-void MntEnt::setdir(const char *data) {
-  dir.setStr(data);
+void MntEnt::setdir(const QString &data) {
+  dir = data;
 }
 
-void MntEnt::settype(const char *data) {
-  type.setStr(data);
+void MntEnt::settype(const QString &data) {
+  type = data;
 }
 
-void MntEnt::setopts(const char *data) {
-  opts.setStr(data);
+void MntEnt::setopts(const QString &data) {
+  opts = data;
 }
 
-void MntEnt::setquotafilename(const char *data) {
-  quotafilename.setStr(data);
+void MntEnt::setquotafilename(const QString &data) {
+  quotafilename = data;
 }
 
 Mounts::Mounts() {
@@ -88,18 +91,20 @@ Mounts::Mounts() {
     if (!CORRECT_FSTYPE((const char *)mt->mnt_fstype))
       continue;
 
-    quotafilename.sprintf("%s%s%s", mt->mnt_mountp,
-                          (mt->mnt_mountp[strlen(mt->mnt_mountp) - 1] == '/') ? "" : "/",
-                          _KU_QUOTAFILENAME);
+    quotafilename = QString("%1%2%3")
+                          .arg(mt->mnt_mountp)
+                          .arg((mt->mnt_mountp[strlen(mt->mnt_mountp) - 1] == '/') ? "" : "/")
+                          .arg(_KU_QUOTAFILENAME);
 #elif BSD /* Heh, heh, so much for standards, eh Bezerkely? */
   while ((mt=getfsent()) != NULL) {
     if (strstr(mt->fs_mntops,"quota")==NULL)
       continue;
     if (strcasecmp(mt->fs_vfstype,"ufs") != 0)
       continue;
-    quotafilename.sprintf("%s%s%s",mt->fs_file,
- 	                  (mt->fs_file[strlen(mt->fs_file) -1] == '/') ? "" : "/",
- 		          _KU_QUOTAFILENAME);
+    quotafilename = QString("%1%2%3")
+                          .arg(mt->fs_file)
+                          .arg((mt->fs_file[strlen(mt->fs_file) -1] == '/') ? "" : "/")
+ 		                      .arg(_KU_QUOTAFILENAME);
 #else
   fp = setmntent(MNTTAB, "r");
   while ((mt = getmntent(fp)) != (struct mntent *)0) {
@@ -109,9 +114,10 @@ Mounts::Mounts() {
     if (!CORRECT_FSTYPE((const char *)mt->mnt_type))
       continue;
 
-    quotafilename.sprintf("%s%s%s", mt->mnt_dir,
-                          (mt->mnt_dir[strlen(mt->mnt_dir) - 1] == '/') ? "" : "/",
-                          _KU_QUOTAFILENAME);
+    quotafilename = QString("%1%2%3")
+                          .arg(mt->mnt_dir)
+                          .arg((mt->mnt_dir[strlen(mt->mnt_dir) - 1] == '/') ? "" : "/")
+                          .arg(_KU_QUOTAFILENAME);
 
 #endif
 
@@ -147,7 +153,7 @@ Mounts::~Mounts() {
   m.clear();
 }
 
-MntEnt *Mounts::getMount(uint num) {
+MntEnt *Mounts::operator[](uint num) {
   return (m.at(num));
 }
 
