@@ -1,40 +1,44 @@
-#include <qvalidator.h>
-#include <kmsgbox.h>
-#include <kstring.h>
+#include "globals.h"
 
 #include <stdio.h>
 #include <stdlib.h>
+
 #ifdef __FreeBSD__
 #include <qdatetm.h>
 #endif
-#include "globals.h"
+#include <qvalidator.h>
+
 #include "propdlg.h"
-#include "propdlg.moc"
 #include "pwddlg.h"
-#include "maindlg.h"
+#include "kglobal_.h"
 #include "misc.h"
 #include "kdatectl.h"
 
-
 #ifdef _KU_QUOTA
-propdlg::propdlg(KUser *auser, Quota *aquota, QWidget *parent, const char *name, int)
+propdlg::propdlg(KUser &AUser, Quota &AQuota, QWidget *parent, const char *name, int)
 #else
-propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
+propdlg::propdlg(KUser &AUser, QWidget *parent, const char *name, int)
 #endif
-       :QDialog(parent, name, FALSE,
-       WStyle_Customize | WStyle_DialogBorder | WStyle_SysMenu |
-       WStyle_MinMax | WType_Modal) {
-  user = auser;
-  olduid = user->getUID();
+ : QDialog(parent, name, FALSE,
+     WStyle_Customize | WStyle_DialogBorder | WStyle_SysMenu |
+     WStyle_MinMax | WType_Modal),
+#ifdef _KU_QUOTA
+ user(AUser), quota(AQuota) 
+#else
+ user(AUser)
+#endif
+{
+
 #ifdef __FreeBSD__
   QDateTime *epoch = new QDateTime();
   QDateTime *temp_time = new QDateTime();
 #endif
 
 #ifdef _KU_QUOTA
-  if (aquota == NULL)
+  if (&AQuota == NULL)
     is_quota = 0;
-  quota = aquota;
+  else
+    quota = AQuota;
   chquota = 0;
 #endif
 
@@ -51,11 +55,11 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
 
   w1 = new QWidget(this, "wd_Password");
 
-  leuser = addLabel(w1, "leuser", 10, 27, 150, 27, user->getName());
+  leuser = addLabel(w1, "leuser", 10, 27, 150, 27, user.getName());
   QToolTip::add(leuser, i18n("User name"));
   l1 = addLabel(w1, "ml1", 10, 10, 50, 20, i18n("User login"));
   leid = addLineEdit(w1, "leid", 200, 30, 70, 22, "");
-  QObject::connect(leid, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(leid, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(leid, i18n("User identificator"));
   l2 = addLabel(w1, "ml2", 200, 10, 50, 20, i18n("User id"));
 
@@ -65,7 +69,7 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
   QObject::connect(pbsetpwd, SIGNAL(clicked()), this, SLOT(setpwd()));
 
   lefname = addLineEdit(w1, "lefname", 10, 80, 160, 22, "");
-  QObject::connect(lefname, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(lefname, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(lefname, i18n("Full name"));
   l4 = addLabel(w1, "ml4", 10, 60, 50, 20, i18n("Full name"));
 
@@ -91,12 +95,12 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
   }
 
   leshell->setGeometry(10, 122, 160, 27);
-  QObject::connect(leshell, SIGNAL(activated(const char *)), this, SLOT(shactivated(const char *)));
+  QObject::connect(leshell, SIGNAL(activated(const QString &)), this, SLOT(shactivated(const QString &)));
 
   l5 = addLabel(w1, "ml5", 10, 105, 50, 20, i18n("Login shell"));
 
   lehome = addLineEdit(w1, "lehome", 10, 175, 160, 22, "");
-  QObject::connect(lehome, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(lehome, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
 
   QToolTip::add(lehome, i18n("Home directory"));
   l6 = addLabel(w1, "ml6", 10, 155, 50, 20, i18n("Home directory"));
@@ -105,21 +109,21 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
   // FreeBSD appears to use the comma separated fields in the GECOS entry
   // differently than Linux.
   leoffice = addLineEdit(w1, "leoffice", 10, 220, 160, 22, "");
-  QObject::connect(leoffice, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(leoffice, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(leoffice, i18n("Office"));
   l7 = addLabel(w1, "ml7", 10, 200, 50, 20, i18n("Office"));
 
   ld7 = addLabel(w1, "mld7", 190, 225, 50, 20, i18n("Office description"));
 
   leophone = addLineEdit(w1, "leophone", 10, 265, 160, 22, "");
-  QObject::connect(leophone, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(leophone, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(leophone, i18n("Office phone"));
   l8 = addLabel(w1, "ml8", 10, 245, 50, 20, i18n("Office phone"));
 
   ld8 = addLabel(w1, "mld8", 190, 270, 50, 20, i18n("Office phone number"));
 
   lehphone = addLineEdit(w1, "lehphone", 10, 310, 160, 22, "");
-  QObject::connect(lehphone, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(lehphone, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(lehphone, i18n("Home phone"));
   l9 = addLabel(w1, "ml9", 10, 290, 50, 20, i18n("Home phone"));
 
@@ -131,7 +135,7 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
   w5 = new QWidget(this, "wd_Extended");
 
   leclass = addLineEdit(w5, "leclass", 10, 80, 160, 22, "");
-  QObject::connect(leclass, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(leclass, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(leclass, i18n("Login class"));
   l19 = addLabel(w5, "ml19", 10, 60, 50, 20, i18n("Login class"));
 
@@ -165,20 +169,20 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
 #else
 
   leoffice1 = addLineEdit(w1, "leoffice1", 10, 220, 160, 22, "");
-  QObject::connect(leoffice1, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(leoffice1, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(leoffice1, i18n("The first office"));
   l7 = addLabel(w1, "ml7", 10, 200, 50, 20, i18n("Office1"));
 
   ld7 = addLabel(w1, "mld7", 190, 225, 50, 20, i18n("First office description"));
 
   leoffice2 = addLineEdit(w1, "leoffice2", 10, 265, 160, 22, "");
-  QObject::connect(leoffice2, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(leoffice2, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(leoffice2, i18n("The second office"));
   l8 = addLabel(w1, "ml8", 10, 245, 50, 20, i18n("Office2"));
 
   ld8 = addLabel(w1, "mld8", 190, 270, 50, 20, i18n("Second office description"));
   leaddress = addLineEdit(w1, "leaddress", 10, 310, 160, 22, "");
-  QObject::connect(leaddress, SIGNAL(textChanged(const char *)), this, SLOT(charchanged(const char *)));
+  QObject::connect(leaddress, SIGNAL(textChanged(const QString &)), this, SLOT(charchanged(const QString &)));
   QToolTip::add(leaddress, i18n("Postal address"));
   l9 = addLabel(w1, "ml9", 10, 290, 50, 20, i18n("Address"));
   ld9 = addLabel(w1, "mld9", 190, 315, 50, 20, i18n("Full postal address"));
@@ -192,38 +196,38 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
 
     char buf[1024];
 
-    convertdate(buf, 0, user->getLastChange());
+    convertdate(buf, 0, user.getLastChange());
     leslstchg = addLabel(w2, "leslstchg", 140, 30, 70, 20, buf);
     l16 = addLabel(w2, "ml16", 10, 30, 50, 20, i18n("Last password change"));
 
     lesmin = new KDateCtl(w2, "lesmin", i18n("Password change not allowed"),
                i18n("Date before which password cannot\nbe changed"),
-                  user->getLastChange()+user->getMin(),
-                  user->getLastChange(), 10, 70);
+                  user.getLastChange() + user.getMin(),
+                  user.getLastChange(), 10, 70);
     QObject::connect(lesmin, SIGNAL(textChanged()), this, SLOT(changed()));
 
     lesmax = new KDateCtl(w2, "lesmax", i18n("Password will not expire"),
                           i18n("Date when password expires and\nmust be changed"),
-                          user->getLastChange()+user->getMax(),
-                          user->getLastChange(), 10, 130);
+                          user.getLastChange() + user.getMax(),
+                          user.getLastChange(), 10, 130);
     QObject::connect(lesmax, SIGNAL(textChanged()), this, SLOT(changed()));
 
 
     leswarn = new KDateCtl(w2, "leswarn", i18n("No warning will be given"),
                            i18n("Date after which warning about pending\npassword expiration will be given"),
-                           user->getLastChange()+user->getWarn(),
-                           user->getLastChange(), 10, 190);
+                           user.getLastChange() + user.getWarn(),
+                           user.getLastChange(), 10, 190);
     QObject::connect(leswarn, SIGNAL(textChanged()), this, SLOT(changed()));
 
     lesinact = new KDateCtl(w2, "lesinact", i18n("Account will remain enabled"),
                             i18n("Date when account will be disabled\nif password has expired"),
-                            user->getLastChange()+user->getInactive(),
-                            user->getLastChange(), 10, 250);
+                            user.getLastChange() + user.getInactive(),
+                            user.getLastChange(), 10, 250);
     QObject::connect(lesinact, SIGNAL(textChanged()), this, SLOT(changed()));
 
     lesexpire = new KDateCtl(w2, "lesexpire", i18n("Account never expires"),
                              i18n("Date when account expires and will\nbe disabled"),
-                             user->getExpire(),
+                             user.getExpire(),
                              0, 10, 310);
     QObject::connect(lesexpire, SIGNAL(textChanged()), this, SLOT(changed()));
 
@@ -239,8 +243,8 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
     QToolTip::add(leqmnt, i18n("Filesystem with quotas"));
     leqmnt->clear();
 
-    for (uint i = 0; i<mounts->getMountsNumber(); i++)
-       leqmnt->insertItem(mounts->getMount(i)->getdir());
+    for (uint i = 0; i<kug->getMounts().getMountsNumber(); i++)
+       leqmnt->insertItem(kug->getMounts()[i]->getdir());
 
     leqmnt->setGeometry(250, 20, 160, 27);
     QObject::connect(leqmnt, SIGNAL(highlighted(int)), this, SLOT(mntsel(int)));
@@ -250,13 +254,13 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
 
     leqfs = addLineEdit(w3, "leqfs", 10, 80, 70, 22, "");
     leqfs->setValidator(new QIntValidator(w3, "vaqfs"));
-    QObject::connect(leqfs, SIGNAL(textChanged(const char *)), this, SLOT(qcharchanged(const char *)));
+    QObject::connect(leqfs, SIGNAL(textChanged(const QString &)), this, SLOT(qcharchanged(const QString &)));
     QToolTip::add(leqfs, i18n("Disk space soft quota"));
     l10 = addLabel(w3, "ml10", 95, 85, 50, 20, i18n("Disk space soft quota"));
 
     leqfh = addLineEdit(w3, "leqfh", 10, 120, 70, 22, "");
     leqfh->setValidator(new QIntValidator(w3, "vaqfh"));
-    QObject::connect(leqfh, SIGNAL(textChanged(const char *)), this, SLOT(qcharchanged(const char *)));
+    QObject::connect(leqfh, SIGNAL(textChanged(const QString &)), this, SLOT(qcharchanged(const QString &)));
     QToolTip::add(leqfh, i18n("Disk space hard quota"));
     l11 = addLabel(w3, "ml11", 95, 125, 50, 20, i18n("Disk space hard quota"));
 
@@ -267,20 +271,20 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
 #ifndef BSD
     leqft = addLineEdit(w3, "leqft", 10, 190, 70, 22, "");
     leqft->setValidator(new QIntValidator(w3, "vaqft"));
-    QObject::connect(leqft, SIGNAL(textChanged(const char *)), this, SLOT(qcharchanged(const char *)));
+    QObject::connect(leqft, SIGNAL(textChanged(const QString &)), this, SLOT(qcharchanged(const QString &)));
     QToolTip::add(leqft, i18n("Time limit allowed for Disk space over soft quota"));
     l18 = addLabel(w3, "ml18", 95, 195, 50, 20, i18n("Time limit allowed for Disk space over soft quota"));
 #endif
 
     leqis = addLineEdit(w3, "leqis", 10, 235, 70, 22, "");
     leqis->setValidator(new QIntValidator(w3, "vaqis"));
-    QObject::connect(leqis, SIGNAL(textChanged(const char *)), this, SLOT(qcharchanged(const char *)));
+    QObject::connect(leqis, SIGNAL(textChanged(const QString &)), this, SLOT(qcharchanged(const QString &)));
     QToolTip::add(leqis, i18n("File number soft quota"));
     l12 = addLabel(w3, "ml12", 95, 240, 50, 20, i18n("File number soft quota"));
 
     leqih = addLineEdit(w3, "leqih", 10, 275, 70, 22, "");
     leqih->setValidator(new QIntValidator(w3, "vaqih"));
-    QObject::connect(leqih, SIGNAL(textChanged(const char *)), this, SLOT(qcharchanged(const char *)));
+    QObject::connect(leqih, SIGNAL(textChanged(const QString &)), this, SLOT(qcharchanged(const QString &)));
     QToolTip::add(leqih, i18n("File number hard quota"));
     l13 = addLabel(w3, "ml13", 95, 280, 50, 20, i18n("File number hard quota"));
 
@@ -291,7 +295,7 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
 #ifndef BSD
     leqit = addLineEdit(w3, "leqit", 10, 345, 70, 22, "");
     leqit->setValidator(new QIntValidator(w3, "vaqit"));
-    QObject::connect(leqit, SIGNAL(textChanged(const char *)), this, SLOT(qcharchanged(const char *)));
+    QObject::connect(leqit, SIGNAL(textChanged(const QString &)), this, SLOT(qcharchanged(const QString &)));
     QToolTip::add(leqit, i18n("Time limit allowed for File number over soft quota"));
     l17 = addLabel(w3, "ml17", 95, 350, 50, 20, i18n("Time limit allowed for File number over soft quota"));
 #endif
@@ -343,7 +347,7 @@ propdlg::propdlg(KUser *auser, QWidget *parent, const char *name, int)
 
   cbpgrp = new QComboBox(FALSE, w4, "cbpgrp");
   cbpgrp->setGeometry(250, 30, 160, 30);
-  QObject::connect(cbpgrp, SIGNAL(activated(const char *)), this, SLOT(setpgroup(const char *)));
+  QObject::connect(cbpgrp, SIGNAL(activated(const QString &)), this, SLOT(setpgroup(const QString &)));
 
   tmpQLabel = new QLabel(w4, "Label_3");
   tmpQLabel->setGeometry(100, 35, 140, 20);
@@ -384,14 +388,14 @@ propdlg::~propdlg() {
 void propdlg::loadgroups() {
   uint i;
 
-  for (i = 0; i<groups->count(); i++) {
-    if (groups->group(i)->lookup_user(user->getName()))
-      m_Group->insertItem(groups->group(i)->getName());
+  for (i = 0; i<kug->getGroups().count(); i++) {
+    if (kug->getGroups()[i]->lookup_user(user.getName()))
+      m_Group->insertItem(kug->getGroups()[i]->getName());
     else
-      m_Other->insertItem(groups->group(i)->getName());
+      m_Other->insertItem(kug->getGroups()[i]->getName());
 
-    cbpgrp->insertItem(groups->group(i)->getName());
-    if (groups->group(i)->getGID() == user->getGID())
+    cbpgrp->insertItem(kug->getGroups()[i]->getName());
+    if (kug->getGroups()[i]->getGID() == user.getGID())
       cbpgrp->setCurrentItem(i);
   }
 
@@ -401,7 +405,7 @@ void propdlg::loadgroups() {
     m_Group->setCurrentItem(0);
 }
 
-void propdlg::setpgroup(const char *) {
+void propdlg::setpgroup(const QString &) {
   ischanged = TRUE;
 }
 
@@ -449,28 +453,24 @@ void propdlg::del() {
   ischanged = TRUE;
 }
 
-void propdlg::charchanged(const char *) {
+void propdlg::charchanged(const QString &) {
   ischanged = TRUE;
 }
 
 void propdlg::save() {
-  QString tmp;
-  uint newuid;
-  tmp.setStr(leid->text());
-  newuid = tmp.toInt();
 #ifdef __FreeBSD__
   QDateTime *epoch = new QDateTime();
   QDateTime *temp_time = new QDateTime();
 #endif
   
-  user->setUID(newuid);
+  user.setUID(leid->text().toInt());
+  user.setFullName(lefname->text());
 
-  user->setFullName(lefname->text());
 #ifdef __FreeBSD__
-  user->setOffice(leoffice->text());
-  user->setWorkPhone(leophone->text());
-  user->setHomePhone(lehphone->text());
-  user->setClass(leclass->text());
+  user.setOffice(leoffice->text());
+  user.setWorkPhone(leophone->text());
+  user.setHomePhone(lehphone->text());
+  user.setClass(leclass->text());
 
   // getDate() returns days since the epoch if a date is specified
   // which we convert to seconds since the epoch.
@@ -480,34 +480,34 @@ void propdlg::save() {
 
   temp_time->setTime_t(0);
   *temp_time = temp_time->addDays(lechange->getDate());
-  user->setLastChange(epoch->secsTo(*temp_time));
+  user.setLastChange(epoch->secsTo(*temp_time));
 
   temp_time->setTime_t(0);
   *temp_time = temp_time->addDays(leexpire->getDate());
-  user->setExpire(epoch->secsTo(*temp_time));
+  user.setExpire(epoch->secsTo(*temp_time));
 
   delete epoch;
   delete temp_time;
 #else
-  user->setOffice1(leoffice1->text());
-  user->setOffice2(leoffice2->text());
-  user->setAddress(leaddress->text());
+  user.setOffice1(leoffice1->text());
+  user.setOffice2(leoffice2->text());
+  user.setAddress(leaddress->text());
 #endif
 
-  user->setHomeDir(lehome->text());
+  user.setHomeDir(lehome->text());
   if (leshell->currentItem() != 0)
-    user->setShell(leshell->text(leshell->currentItem()));
+    user.setShell(leshell->text(leshell->currentItem()));
   else
-    user->setShell("");
+    user.setShell("");
 
 #ifdef _KU_SHADOW
   if (is_shadow) {
-    user->setMin(lesmin->getDate()-user->getLastChange());
-    user->setMax(lesmax->getDate()-user->getLastChange());
-    user->setWarn(leswarn->getDate()-user->getLastChange());
-    user->setInactive(lesinact->getDate()-user->getLastChange());
-    user->setExpire(lesexpire->getDate());
-    user->setLastChange(today());
+    user.setMin(lesmin->getDate() - user.getLastChange());
+    user.setMax(lesmax->getDate() - user.getLastChange());
+    user.setWarn(leswarn->getDate() - user.getLastChange());
+    user.setInactive(lesinact->getDate() - user.getLastChange());
+    user.setExpire(lesexpire->getDate());
+    user.setLastChange(today());
   }
 #endif
 }
@@ -515,15 +515,16 @@ void propdlg::save() {
 void propdlg::saveg() {
   uint i;
 
+  const QString &userName = user.getName();
   for (i=0;i<m_Group->count();i++)
-    if (groups->lookup(m_Group->text(i))->lookup_user(user->getName()))
-      groups->lookup(m_Group->text(i))->addUser(user->getName());
+    if (kug->getGroups().lookup(m_Group->text(i))->lookup_user(userName))
+      kug->getGroups().lookup(m_Group->text(i))->addUser(userName);
   
   for (i=0;i<m_Other->count();i++)
-    if (groups->lookup(m_Other->text(i))->lookup_user(user->getName()))
-      groups->lookup(m_Other->text(i))->removeUser(user->getName());
+    if (kug->getGroups().lookup(m_Other->text(i))->lookup_user(userName))
+      kug->getGroups().lookup(m_Other->text(i))->removeUser(userName);
 
-  user->setGID(groups->lookup(cbpgrp->text(cbpgrp->currentItem()))->getGID());
+  user.setGID(kug->getGroups().lookup(cbpgrp->text(cbpgrp->currentItem()))->getGID());
 }
 
 #ifdef _KU_QUOTA
@@ -534,12 +535,12 @@ void propdlg::mntsel(int index) {
   selectuser();
 }
 
-void propdlg::qcharchanged(const char *) {
+void propdlg::qcharchanged(const QString &) {
   isqchanged = TRUE;
 }
 
 void propdlg::saveq() {
-  QuotaMnt *tmpq = quota->getQuotaMnt(chquota);
+  QuotaMnt *tmpq = quota[chquota];
 
   tmpq->setfhard(atol(leqfh->text()));
   tmpq->setfsoft(atol(leqfs->text()));
@@ -553,14 +554,14 @@ void propdlg::saveq() {
 #endif
 }
 #else
-void propdlg::qcharchanged(const char *) {
+void propdlg::qcharchanged(const QString &) {
 }
 
 void propdlg::mntsel(int) {
 }
 #endif
 
-void propdlg::shactivated(const char *text) { 
+void propdlg::shactivated(const QString &text) { 
   int id = leshell->currentItem();
   leshell->changeItem(text, id);
   changed();
@@ -569,61 +570,59 @@ void propdlg::shactivated(const char *text) {
 bool propdlg::check() {
   bool ret = FALSE;
 
-  if (ischanged == TRUE) {
+  if (ischanged) {
     save();
     saveg();
     ret = TRUE;
   }
 
 #ifdef _KU_QUOTA
-  if (isqchanged == TRUE) {
+  if (isqchanged) {
     saveq();
     ret = TRUE;
   }
 #endif
 
-  return (ret);
+  return ret;
 }
 
 void propdlg::selectuser() {
-  QString uname;
+  leuser->setText(user.getName());
 
-  leuser->setText(user->getName());
+  leid->setText(QString("%1").arg(user.getUID()));
+  olduid = user.getUID();
 
-  ksprintf(&uname, "%i",user->getUID());
-  leid->setText(uname);
-
-//  sprintf(uname,"%i",user->getp_gid());
+//  sprintf(uname, "%i", user.getp_gid());
 //  legid->setText(uname);
 
-  lefname->setText(user->getFullName());
+  lefname->setText(user.getFullName());
 
-  if (user->getShell().isEmpty() != TRUE) {
-    int tested = 0;
+  if (user.getShell().isEmpty() != TRUE) {
+    bool tested = FALSE;
     for (int i=0; i<leshell->count(); i++)
-      if (!strcmp(leshell->text(i), user->getShell())) {
-        tested = 1;
+      if (leshell->text(i) == user.getShell()) {
+        tested = TRUE;
         leshell->setCurrentItem(i);
         break;
       }
     if (!tested) {
-      leshell->insertItem(user->getShell());
+      leshell->insertItem(user.getShell());
       leshell->setCurrentItem(leshell->count()-1);
     }
   } else
     leshell->setCurrentItem(0);
 
-  lehome->setText(user->getHomeDir());
+  lehome->setText(user.getHomeDir());
 #ifdef __FreeBSD__
-  leoffice->setText(user->getOffice());
-  leophone->setText(user->getWorkPhone());
-  lehphone->setText(user->getHomePhone());
-  leclass->setText(user->getClass());
+  leoffice->setText(user.getOffice());
+  leophone->setText(user.getWorkPhone());
+  lehphone->setText(user.getHomePhone());
+  leclass->setText(user.getClass());
   // the date fields get set when the dialogue is built
 #else
-  leoffice1->setText(user->getOffice1());
-  leoffice2->setText(user->getOffice2());
-  leaddress->setText(user->getAddress());
+  leoffice1->setText(user.getOffice1());
+  leoffice2->setText(user.getOffice2());
+  leaddress->setText(user.getAddress());
 #endif
 
 #ifdef _KU_QUOTA
@@ -632,30 +631,17 @@ void propdlg::selectuser() {
     if (chquota != -1)
       q = chquota;
 
-    ksprintf(&uname,"%li",quota->getQuotaMnt(q)->getfsoft());
-    leqfs->setText(uname);
-
-    ksprintf(&uname,"%li",quota->getQuotaMnt(q)->getfhard());
-    leqfh->setText(uname);
-
-    ksprintf(&uname,"%li",quota->getQuotaMnt(q)->getisoft());
-    leqis->setText(uname);
-
-    ksprintf(&uname,"%li",quota->getQuotaMnt(q)->getihard());
-    leqih->setText(uname);
-
-    ksprintf(&uname,"%li",quota->getQuotaMnt(q)->getfcur());
-    leqfcur->setText(uname);
-
-    ksprintf(&uname,"%li",quota->getQuotaMnt(q)->geticur());
-    leqicur->setText(uname);
+    QuotaMnt *qm = quota[q];
+    leqfs->setText(QString("%1").arg(qm->getfsoft()));
+    leqfh->setText(QString("%1").arg(qm->getfhard()));
+    leqis->setText(QString("%1").arg(qm->getisoft()));
+    leqih->setText(QString("%1").arg(qm->getihard()));
+    leqfcur->setText(QString("%1").arg(qm->getfcur()));
+    leqicur->setText(QString("%1").arg(qm->geticur()));
 
 #ifndef BSD
-    ksprintf(&uname,"%li",quota->getQuotaMnt(q)->getftime());
-    leqft->setText(uname);
-
-    ksprintf(&uname,"%li",quota->getQuotaMnt(q)->getitime());
-    leqit->setText(uname);
+    leqft->setText(QString("%1").arg(qm->getftime()));
+    leqit->setText(QString("%1").arg(qm->getitime()));
 #endif
   }
 #endif
@@ -671,20 +657,16 @@ void propdlg::setpwd() {
 }
 
 void propdlg::ok() {
-  QString tmp;
-  uint newuid;
-  tmp.setStr(leid->text());
-  newuid = tmp.toInt();
+  uid_t newuid = leid->text().toInt();
 
   if (olduid != newuid)
-    if (users->lookup(newuid) != NULL) {
-      tmp.sprintf(i18n("User with UID %u already exists"), newuid);
-      err->addMsg(tmp, STOP);
+    if (kug->getUsers().lookup(newuid) != NULL) {
+      err->addMsg(i18n("User with UID %1 already exists").arg(newuid));
       err->display();
       return;
     }
     
-  if (check() == TRUE)
+  if (check())
     accept();
   else
     reject();
@@ -694,14 +676,3 @@ void propdlg::cancel() {
   reject();
 }
 
-
-
-
-
-
-
-
-
-
-
-
