@@ -7,25 +7,29 @@
 
  *********************************************************************/
 
-#include "userDefaultsPage.h"
-
-#define Inherited userDefaultsPageData
-
-#include "userDefaultsPage.moc"
-#include "userDefaultsPageData.moc"
 
 #include <kapp.h>
-
+#include <qlayout.h>
+#include <qlabel.h>
 #include "globals.h"
+#include "userDefaultsPage.h"
+#include <klocale.h>
+#include <stdio.h>
 
-userDefaultsPage::userDefaultsPage
-(
+userDefaultsPage::userDefaultsPage(
 	QWidget* parent,
 	const char* name
 )
 	:
-	Inherited( parent, name )
-{
+	QWidget( parent, name) {
+  QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
+
+  QLabel *l;
+  l = new QLabel(i18n("Shell"), this);
+  l->setFixedSize(l->sizeHint());
+  tl->addWidget(l, 0, AlignLeft);
+  shell = new QComboBox(this);  
+  
   shell->clear();
   shell->insertItem(i18n("<Empty>"));
 
@@ -44,11 +48,36 @@ userDefaultsPage::userDefaultsPage
     }
     fclose(f);
   }
+  shell->setMinimumSize(shell->sizeHint());
+  tl->addWidget(shell, 0, AlignLeft);
+
+  tl->addStretch(1);
+
+  l = new QLabel(i18n("Base of home directories"), this);
+  l->setFixedSize(l->sizeHint());
+  tl->addWidget(l, 0, AlignLeft);
+  home=new QLineEdit(this);
+  home->setFixedSize(home->sizeHint());
+  tl->addWidget(home, 0, AlignLeft);
+
+  tl->addStretch(2);
+
+  createHomeDir = new QCheckBox(i18n("Create home dir"), this);
+  createHomeDir->setFixedSize(createHomeDir->sizeHint());
+  tl->addWidget(createHomeDir, 0, AlignLeft);
+
+  copySkel = new QCheckBox(i18n("Copy skeleton to home dir"), this);
+  copySkel->setFixedSize(copySkel->sizeHint());
+  tl->addWidget(copySkel, 0, AlignLeft);
+
+  userPrivateGroup = new QCheckBox(i18n("User Private Group"), this);
+  userPrivateGroup->setFixedSize(userPrivateGroup->sizeHint());
+  tl->addWidget(userPrivateGroup, 0, AlignLeft);
+  tl->activate();
 }
 
 
-userDefaultsPage::~userDefaultsPage()
-{
+userDefaultsPage::~userDefaultsPage() {
 }
 
 const char *userDefaultsPage::getShell() const {
@@ -97,4 +126,3 @@ void userDefaultsPage::setCopySkel(bool data) {
 void userDefaultsPage::setUserPrivateGroup(bool data) {
   userPrivateGroup->setChecked(data);
 }
-
