@@ -10,21 +10,20 @@
 #ifndef userDefaultsPage_included
 #define userDefaultsPage_included
 
-#include "userDefaultsPageData.h"
+#include <qlineedit.h>
+#include <qcombobox.h>
+#include <qcheckbox.h>
 
-class userDefaultsPage : public userDefaultsPageData
-{
+class userDefaultsPage : public QWidget {
     Q_OBJECT
 
 public:
-
-    userDefaultsPage
-    (
+    userDefaultsPage(
         QWidget* parent = NULL,
         const char* name = NULL
     );
 
-    virtual ~userDefaultsPage();
+  ~userDefaultsPage();
 
   const char *getShell() const;
   const char *getHomeBase() const;
@@ -37,5 +36,13 @@ public:
   void setCreateHomeDir(bool data);
   void setCopySkel(bool data);
   void setUserPrivateGroup(bool data);
+
+private:
+  QComboBox *shell;
+  QLineEdit *home;
+  QCheckBox* createHomeDir;
+  QCheckBox* copySkel;
+  QCheckBox* userPrivateGroup;
 };
 #endif // userDefaultsPage_included
+
